package com.caimei365.commodity.components;


import com.caimei365.commodity.mapper.PriceMapper;
import com.caimei365.commodity.mapper.PromotionsMapper;
import com.caimei365.commodity.model.dto.Sku;
import com.caimei365.commodity.model.dto.VipSkuPriceDto;
import com.caimei365.commodity.model.vo.*;
import com.caimei365.commodity.utils.ImageUtils;
import com.caimei365.commodity.utils.MathUtil;
import com.google.common.util.concurrent.AtomicDouble;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.concurrent.atomic.AtomicReference;
import java.util.stream.Collectors;
import java.util.stream.IntStream;

/**
 * Description
 *
 * @author : Charles
 * @date : 2020/6/22
 */
@Slf4j
@Service
public class PriceUtilService {
    @Resource
    private PriceMapper priceMapper;
    @Resource
    private PromotionsMapper promotionsMapper;
    @Value("${caimei.wwwDomain}")
    private String domain;

    /**
     * 根据价格返回价格等级
     *
     * @param price 价格
     * @return priceGrade 价格等级
     */
    public Integer getPriceGrade(Double price) {
        int grade = 1;
        price = price != null ? price : 0d;
        if (price > 50 * 10000) {
            grade = 5;
        } else if (price > 25 * 10000) {
            grade = 4;
        } else if (price > 10 * 10000) {
            grade = 3;
        } else if (price > 2.5 * 10000) {
            grade = 2;
        }
        return grade;
    }

    /**
     * 设置阶梯价展示数据
     *
     * @param ladderPrices List<LadderPriceVo>
     * @param tax          TaxVo
     */
    public void setLadderPriceList(List<LadderPriceVo> ladderPrices, TaxVo tax) {
        IntStream.range(0, ladderPrices.size()).forEach(i -> {
            //税费标志
            boolean taxFlag = 0 == tax.getIncludedTax() && 1 == tax.getInvoiceType() || 2 == tax.getInvoiceType();
            //添加税费
            if (taxFlag) {
                BigDecimal taxFee = MathUtil.div(MathUtil.mul(ladderPrices.get(i).getBuyPrice(), tax.getTaxPoint()), 100, 2);
                ladderPrices.get(i).setBuyPrice(MathUtil.add(ladderPrices.get(i).getBuyPrice(), taxFee).doubleValue());
            }
            if (i == ladderPrices.size() - 1) {
                ladderPrices.get(i).setMaxNum(0);
                ladderPrices.get(i).setNumRange("≥" + ladderPrices.get(i).getBuyNum());
            } else {
                ladderPrices.get(i).setMaxNum(ladderPrices.get(i + 1).getBuyNum());
                String buyNumRangeShow = ladderPrices.get(i).getBuyNum() + "~" + (ladderPrices.get(i + 1).getBuyNum() - 1);
                ladderPrices.get(i).setNumRange(buyNumRangeShow);
            }
        });
    }

    /**
     * 根据用户id设置详细价格
     * ind=1不屏蔽价格
     *
     * @param price  商品价格类
     * @param userId 用户Id
     */
    public void setPriceByUserId(PriceVo price, Integer userId, Integer ind) {
        // 根据用户Id查询用户身份: 0个人，1协销，2会员机构，3供应商，4普通机构
        Integer identity = priceMapper.getIdentityByUserId(userId);
        if (null == identity) {
            identity = 0;
        }
        // priceFlag: 0公开价格，1不公开价格，2仅对会员机构公开，3仅对医美机构公开
        Integer priceFlag = null != price.getPriceFlag() ? price.getPriceFlag() : 0;
        // 会员机构类型：1医美，2生美
        Integer clubType = 0;
        if (identity == 2) {
            clubType = priceMapper.getClubTypeById(userId);
            if (null == clubType) {
                clubType = 0;
            }
        }
        // 根据用户Id查询超级会员id
        Integer svipUserId = priceMapper.getSvipUserIdByUserId(userId);
        // 超级会员标识
        boolean isSuperVip = null != svipUserId;
        // 根据商品id，用户身份 查询商品活动
        PromotionsVo promotions = promotionsMapper.getPricePromotions(price.getProductId(), identity);
        price.setActStatus(0);
        // 用户身份: 2-会员机构, 4-普通机构
        price.setUserIdentity(identity);
        //是否是供应商自己的商品
        boolean isShopOwn = false;
        if (identity == 3) {
            // 根据用户Id查询供应商Id
            Integer shopId = priceMapper.getShopIdByUserId(userId);
            if (null != shopId && shopId.equals(price.getShopId())) {
                isShopOwn = true;
            }
        }
        // 设置价格标志(协销|价格公开|仅对医美机构公开|仅对会员机构公开|供应商自己的商品)
        boolean setFlag = identity == 1 || priceFlag == 0 || (priceFlag == 3 && clubType == 1) || (priceFlag == 2 && (identity == 2 || isSuperVip)) || isShopOwn;

        List<Sku> skus = priceMapper.findSkus(price.getProductId());
        int size = skus.size();
        //税费标志
        boolean taxFlag = "0".equals(price.getIncludedTax()) && ("1".equals(price.getInvoiceType()) || "2".equals(price.getInvoiceType()));
        //未设置价格
        price.setLadderPriceFlag(0);
        price.setPrice(skus.get(0).getPrice());
        price.setSkuId(skus.get(0).getSkuId());
        price.setMinBuyNumber(skus.get(0).getMinBuyNumber());
        price.setUnit(skus.get(0).getUnit());
        price.setStock(skus.get(0).getStock());
        skus.forEach(s -> {
            s.setOriginalPrice(s.getPrice());
            s.setPriceGrade(getPriceGrade(s.getPrice()));
            if (setFlag && 1 == price.getSvipProductFlag()) {
                // 超级会员优惠商品,不参与促销活动（普通机构购买该商品可参与店铺促销）/阶梯价/复购价
                s.setLadderPriceFlag(0);
                // 超级会员优惠价
                BigDecimal svipDiscountPrice = BigDecimal.valueOf(null == s.getDiscountPrice() ? 0 : s.getDiscountPrice());
                if (1 == s.getPriceType()) {
                    // 折扣价
                    // 超级会员用户设置优惠价
                    svipDiscountPrice = MathUtil.div(MathUtil.mul(s.getPrice(), s.getDiscount()), 100, 2);
                    s.setSvipPriceTag(MathUtil.div(s.getDiscount(), 10, 1) + "折");
                } else if (2 == s.getPriceType()) {
                    s.setPrice(svipDiscountPrice.doubleValue());
                    if (taxFlag) {
                        //添加税费
                        BigDecimal thisTaxFee = MathUtil.div(MathUtil.mul(svipDiscountPrice, price.getTaxRate()), 100, 2);
                        svipDiscountPrice = MathUtil.add(svipDiscountPrice, thisTaxFee);
                    }
                    // 直接优惠价
                    // 超级会员用户设置优惠价
                    s.setSvipPriceTag("￥" + svipDiscountPrice.doubleValue());
                }
            } else if (null != promotions) {
                // 促销活动
                price.setActStatus(1);
                s.setLadderPriceFlag(0);
                if (promotions.getMode() == 3) {
                    // 获取赠品
                    List<ProductItemVo> giftList = promotionsMapper.getPromotionGifts(promotions.getId());
                    promotions.setGiftList(giftList);
                }
                if (promotions.getType() == 1 && promotions.getMode() == 1) {
                    // 单品优惠价的时候，取当前sku的touchprice
                    Double touchPrice = priceMapper.getTouchPriceBySku(s.getSkuId(), promotions.getId());
                    s.setPrice(touchPrice);
                    price.setPrice(touchPrice);
                    promotions.setTouchPrice(touchPrice);
                }
                price.setPromotions(promotions);
            } else {
                if (null != userId) {
                    if (1 == s.getLadderPriceFlag()) {
                        // sku的阶梯价
                        LadderPriceVo lowerBuyNum = priceMapper.findMaxLadderPrice(s.getSkuId());
                        s.setMinBuyNumber(lowerBuyNum.getBuyNum());
                        s.setPrice(lowerBuyNum.getBuyPrice());
                        s.setStock(lowerBuyNum.getStock());
                        s.setUnit(lowerBuyNum.getUnit());
                        List<LadderPriceVo> ladderPrices = priceMapper.getLadderPricesByProductId(s.getSkuId());
                        TaxVo tax = priceMapper.getTaxByProductId(price.getProductId());
                        if (!CollectionUtils.isEmpty(ladderPrices)) {
                            setLadderPriceList(ladderPrices, tax);
                        }
                        s.setLadderPriceList(ladderPrices);
                        price.setLadderPriceFlag(1);
                        if (1 == size) {
                            //1.对于只有一个SKU的商品，各个商品列表直接显示机构价即可:若是阶梯价，则显示第一级阶梯的价格:
                            price.setSkuId(ladderPrices.get(0).getSkuId());
                            price.setPrice(ladderPrices.get(0).getBuyPrice());
                            price.setMinBuyNumber(ladderPrices.get(0).getBuyNum());
                            price.setStock(ladderPrices.get(0).getStock());
                            price.setUnit(ladderPrices.get(0).getUnit());
                        } else {
                            //2.对于有多个SKU的商品，各个商品列表显示所有SKU中最低的价格:
                            // 若SKU中，全部都是阶梯价，则显示所有SKU中第一级阶梯的价格中的最低价，
                            // 若SKU中，使用阶梯价和不使用阶梯价(只是用机构价》并存，则用机构价和第一级阶梯价比大小，展示最小的价格
                            // skuid分组取第一阶梯中最便宜的
                            ProductItemVo lowLadderPrice = priceMapper.findLowPriceOfAll(price.getProductId());
                            ProductItemVo lowAllPrice = priceMapper.findLowPriceOfPrice(price.getProductId());
                            if (null != lowLadderPrice) {
                                ProductItemVo productItemVo = lowLadderPrice.getPrice() > lowAllPrice.getPrice() ? lowAllPrice : lowLadderPrice;
                                price.setPrice(productItemVo.getPrice());
                                price.setSkuId(productItemVo.getSkuId());
                                price.setMinBuyNumber(productItemVo.getMinBuyNumber());
                                price.setUnit(productItemVo.getUnit());
                                price.setStock(productItemVo.getStock());
                            } else {
                                price.setPrice(lowAllPrice.getPrice());
                                price.setSkuId(lowAllPrice.getSkuId());
                                price.setMinBuyNumber(lowAllPrice.getMinBuyNumber());
                                price.setUnit(lowAllPrice.getUnit());
                                price.setStock(lowAllPrice.getStock());
                            }
                        }
                    }
                    /* else {
                        // 复购价
                        Double repurchase = priceMapper.getRepurchasePrice(s.getSkuId(), userId);
                        if (null != repurchase && repurchase > 0) {
                            s.setPrice(repurchase);
                            s.setRepurchaseFlag(1);
                            s.setLadderPriceFlag(0);
                        }
                    }*/
                }
            }
            //添加税费
            if (taxFlag) {
                BigDecimal thisTaxFee = MathUtil.div(MathUtil.mul(s.getPrice(), price.getTaxRate()), 100, 2);
                s.setPrice(MathUtil.add(s.getPrice(), thisTaxFee).doubleValue());
                BigDecimal originalTaxFee = MathUtil.div(MathUtil.mul(s.getOriginalPrice(), price.getTaxRate()), 100, 2);
                s.setOriginalPrice(MathUtil.add(s.getOriginalPrice(), originalTaxFee).doubleValue());
            }
        });
        // price添加税费
        if (taxFlag) {
            BigDecimal thisTaxFee = MathUtil.div(MathUtil.mul(price.getPrice(), price.getTaxRate()), 100, 2);
            price.setPrice(MathUtil.add(price.getPrice(), thisTaxFee).doubleValue());
            BigDecimal originalTaxFee = MathUtil.div(MathUtil.mul(price.getOriginalPrice(), price.getTaxRate()), 100, 2);
            price.setOriginalPrice(MathUtil.add(price.getOriginalPrice(), originalTaxFee).doubleValue());
        }
        if (1 == price.getSvipProductFlag() && setFlag) {
            price.setPrice(skus.get(0).getPrice());
            price.setSvipPriceTag(skus.get(0).getSvipPriceTag());
        }
        price.setOriginalPrice(skus.get(0).getOriginalPrice());
        price.setSkus(skus);
        // 身份不对
        if (!setFlag && 1 != ind) {
            price.setSkus(priceMapper.findSkusOutOfPrice(price.getProductId()));
            price.setUserIdentity(0);
            if (null != promotions) {
                price.setActStatus(1);
                promotions.setTouchPrice(0d);
                promotions.setReducedPrice(0d);
                price.setPromotions(promotions);
            } else {
                // 默认非促销活动状态
                price.setActStatus(0);
            }
        }
    }

    /**
     * 设置商品主图及价格
     * ind=1不屏蔽价格
     *
     * @param userId  用户Id
     * @param product ProductItemVo
     */
    public void setProductDetails(Integer userId, ProductItemVo product, Integer ind) {
        // 设置图片
        product.setImage(ImageUtils.getImageURL("product", product.getImage(), 0, domain));
        // 数据库获取基本价格信息
        PriceVo price = priceMapper.getDetailPrice(product.getProductId());
        // 根据用户id设置详细价格
        setPriceByUserId(price, userId, ind);
        // 设置价格
        product.setActStatus(price.getActStatus());
        product.setPromotions(price.getPromotions());
        product.setUserIdentity(price.getUserIdentity());
        product.setSvipProductFlag(price.getSvipProductFlag());
        product.setSvipPriceTag(price.getSvipPriceTag());
        product.setPrice(price.getPrice());
        product.setSkuId(price.getSkuId());
        product.setOriginalPrice(price.getOriginalPrice());
        product.setPriceGrade(getPriceGrade(price.getPrice()));
        product.setMinBuyNumber(price.getMinBuyNumber());
        product.setUnit(price.getUnit());
        product.setStock(price.getStock());
        product.setSkus(price.getSkus());
    }

    /**
     * 设置供应商商品主图及价格
     *
     * @param product ProductItemVo
     */
    public void setShopProductDetails(ProductItemVo product) {
        // 设置图片
        product.setImage(ImageUtils.getImageURL("product", product.getImage(), 0, domain));
        // 数据库获取基本价格信息
        PriceVo price = null;
        if ( StringUtils.isNotBlank(product.getGroundMall()) && product.getGroundMall().contains("0")) {
            price = priceMapper.getMinPrice(product.getProductId());
        } else {
            price = priceMapper.getOrganizeMinPrice(product.getProductId());
        }
        // 设置价格
        product.setPrice(price.getPrice());
        product.setNormalPrice(price.getNormalPrice());
        product.setSkuId(price.getSkuId());
    }

    /**
     * 设置商品主图及价格 -- 组织
     *
     * @param userId  用户Id
     * @param product ProductItemVo
     */
    public void setOrganizeProductDetails(Integer userId, ProductItemVo product) {
        Integer organizeId = priceMapper.getOrganize(userId);
        organizeId = organizeId == null?0:organizeId;
        // 设置图片
        product.setImage(ImageUtils.getImageURL("product", product.getImage(), 0, domain));
        List<MallProductSkuVo> organizeSkus = priceMapper.findOrganizeSkus(product.getProductId());
        if (null != organizeSkus) {
            product.setPrice(organizeSkus.get(0).getPrice());
            product.setMinBuyNumber(organizeSkus.get(0).getMinBuyNumber());
            product.setUnit(organizeSkus.get(0).getUnit());
            product.setOrganizeSkus(organizeSkus);
            product.setSkuId(organizeSkus.get(0).getId());
//            product.setSkus(organizeSkus);
            //设置展示的价格等级
            product.setPriceGrade(getPriceGrade(product.getPrice()));
        }
        // 价格等级
        organizeSkus.forEach(o -> {
            o.setPriceGrade(getPriceGrade(o.getPrice()));
        });
    }

}
