package com.caimei365.commodity.controller;

import com.caimei365.commodity.annotation.Statistics;
import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.po.ProductParameterPo;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.vo.*;
import com.caimei365.commodity.service.HeheService;
import com.caimei365.commodity.service.PageService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang.StringUtils;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2022/3/29
 */
@Api(tags = "呵呵商品API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/commodity/hehe")
public class HeheApi {

    private final HeheService heheService;

    /**
     * 轮播图
     */
    @ApiOperation("轮播图")
    @GetMapping("/home/carousel")
    public ResponseJson<List<HeHeImageVo>> getHomeCarousel() {
        return heheService.getHomeCarousel();
    }

    /**
     * 获取首页分类列表
     */
    @ApiOperation("首页分类菜单")
    @GetMapping("/home/type")
    public ResponseJson<List<BigTypeVo>> getHomeTypeList() {
        return heheService.getHomeTypeList();
    }

    /**
     * 获取商品列表
     */
    @ApiOperation("商品列表")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "listType", value = "列表类型:1首页搜索商品列表，2首页分类商品列表，" +
                    "3首页楼层商品列表.4二级分类商品列表,5优惠券商品列表,6活动商品列表"),
            @ApiImplicitParam(required = false, name = "name", value = "搜索商品名称(1)"),
            @ApiImplicitParam(required = false, name = "homeTypeId", value = "首页分类id(2)"),
            @ApiImplicitParam(required = false, name = "homeFloorId", value = "首页楼层id(3)"),
            @ApiImplicitParam(required = false, name = "smallTypeId", value = "二级分类id(4)"),
            @ApiImplicitParam(required = false, name = "couponId", value = "优惠券id(5)"),
            @ApiImplicitParam(required = false, name = "activityId", value = "活动id(6)"),
            @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
            @ApiImplicitParam(required = false, name = "sortType", value = "排序类型：1综合，2价格升序，3价格降序，4最新"),
            @ApiImplicitParam(required = false, name = "productIds", value = "综合排序已查出的商品id，以，隔开"),
            @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
            @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/product/list")
    public ResponseJson<Map<String,Object>> getProductList(Integer listType, Integer homeTypeId, Integer homeFloorId, Integer smallTypeId,
                                                                    Integer userId, String name, Integer couponId, Integer activityId, String productIds,
                                                                    Integer sortType,
                                                                    @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                    @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        if (null == listType) {
            return ResponseJson.error("列表类型不能为空", null);
        }
        if (1 == listType && StringUtils.isEmpty(name)) {
            return ResponseJson.error("搜索关键词不能为空", null);
        }
        if (2 == listType && (null == homeTypeId || 0 == homeTypeId)) {
            return ResponseJson.error("首页分类id不能为空", null);
        }
        if (3 == listType && (null == homeFloorId || 0 == homeFloorId)) {
            return ResponseJson.error("首页楼层id不能为空", null);
        }
        if (4 == listType && (null == smallTypeId || 0 == smallTypeId)) {
            return ResponseJson.error("二级分类id不能为空", null);
        }
        if (5 == listType && (null == couponId || 0 == couponId)) {
            return ResponseJson.error("优惠券id不能为空", null);
        }
        if (6 == listType && (null == activityId || 0 == activityId)) {
            return ResponseJson.error("活动id不能为空", null);
        }
        return heheService.getProductList(listType, homeTypeId, homeFloorId, smallTypeId, couponId, activityId, userId, name, productIds, sortType, pageNum, pageSize);
    }

    @ApiOperation("首页楼层数据")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "userId", value = "用户id")
    })
    @GetMapping("/home/init")
    public ResponseJson<Map<String, Object>> getHomeData(Integer userId) {
        return heheService.getHomeData(userId);
    }

    @ApiOperation("活动专区")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "分销者用户id", required = true),
            @ApiImplicitParam(name = "pageNum", value = "第几页", required = false),
            @ApiImplicitParam(name = "pageSize", value = "一页多少条", required = false)
    })
    @GetMapping("/activity/list")
    public ResponseJson<PaginationVo<HeHeActivityVo>> getActivityList(Integer userId,
                                                                      @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                                                      @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) {
        if (null == userId) {
            return ResponseJson.error("参数异常，分销者用户id不能为空", null);
        }
        return heheService.getActivityList(userId, pageNum, pageSize);
    }

    /*@ApiOperation("活动详情")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "分销者用户id", required = true),
            @ApiImplicitParam(name = "activityId", value = "活动id", required = true),
            @ApiImplicitParam(name = "pageNum", value = "第几页", required = false),
            @ApiImplicitParam(name = "pageSize", value = "一页多少条", required = false)
    })
    @GetMapping("/activity/details")
    public ResponseJson<Map<String, Object>> getActivityDetails(Integer userId, Integer activityId,
                                                             @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                                             @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) {
        if (userId == null || activityId == null) {
            return ResponseJson.error("参数异常", null);
        }
        return heheService.getActivityDetails(userId, activityId, pageNum, pageSize);
    }*/

    @ApiOperation("商品详情")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "productId", required = true, value = "商品Id"),
            @ApiImplicitParam(name = "userId", required = true, value = "机构用户Id")
    })
    @GetMapping("/details")
    public ResponseJson<HeheProductVo> getProductDetails(Integer productId, Integer userId) {
        return heheService.getProductDetails(productId, userId);
    }
}
