package com.caimei365.commodity.controller;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.vo.MallOrganizeProductVo;
import com.caimei365.commodity.service.MallOrganizeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/4/28
 */
@Api(tags = "外部商城")
@RestController
@RequestMapping("/commodity/MallOrganize")
public class MallOrganizeApi {

    @Autowired private MallOrganizeService mallOrganizeService;

    /**
     * 联合丽格小程序首页
     * @return
     */
    @ApiOperation("小程序首页")
    @ApiImplicitParams({
            @ApiImplicitParam(readOnly = true, name = "organizeId", value = "组织Id 1 联合丽格")
    })
    @GetMapping("/mall/init")
    public ResponseJson<Map<String, Object>> getMallHome(Integer organizeId) {
        if (null == organizeId) {
            return ResponseJson.error(-1,"商城类型不能为空",null);
        }
        return mallOrganizeService.getMallHome(organizeId);
    }

    /**
     * 活动详情
     * @param organizeId
     * @param activeId
     * @return
     */
    @ApiOperation("活动详情")
    @ApiImplicitParams({
            @ApiImplicitParam(readOnly = true, name = "organizeId", value = "组织Id 1 联合丽格"),
            @ApiImplicitParam(readOnly = true, name = "activeId", value = "活动Id")
    })
    @GetMapping("/mall/detail")
    public ResponseJson<Map<String,Object>> getMenu(Integer organizeId,  Integer activeId) {
        if (null == organizeId) {
            return ResponseJson.error(-1,"商城类型不能为空",null);
        }
        if (null == activeId) {
            return ResponseJson.error(-1,"菜单id不能为空",null);
        }

        return mallOrganizeService.getMenu(organizeId,  activeId);
    }

    /**
     * 活动宣传图商品
     * @param imageId
     * @return
     */
    @GetMapping("/mall/activeProduct")
    public ResponseJson<List<MallOrganizeProductVo>> activeProduct(Integer imageId) {
        if (null == imageId) {
            return ResponseJson.error(-1,"活动宣传图id不能为空",null);
        }
        return mallOrganizeService.activeProduct(imageId);
    }

    /**
     * 商品楼层详情
     * @param floorId
     * @return
     */
    @ApiOperation("商品楼层详情")
    @ApiImplicitParams({
            @ApiImplicitParam(readOnly = true, name = "floorId", value = "楼层Id")
    })
    @GetMapping("/mall/organizeProducts")
    public ResponseJson<List<MallOrganizeProductVo>> getOrganizeProducts(Integer floorId) {
        if (null == floorId) {
            return ResponseJson.error(-1,"楼层Id不能为空",null);
        }
        return mallOrganizeService.getOrganizeProducts(floorId);
    }

    /**
     * 专题活动详情 只有一个已启用状态的活动
     * @return
     */
    @ApiOperation("专题活动详情 只有一个已启用状态的活动")
    @GetMapping("/mall/getThemeInfo")
    public ResponseJson<Map<String, Object>> getThemeInfo() {
        return mallOrganizeService.getThemeInfo();
    }
}
