package com.caimei365.commodity.controller;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.dto.ProcurementDto;
import com.caimei365.commodity.model.po.ProcurePo;
import com.caimei365.commodity.service.ProcurementService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/4/26
 */
@Api(tags = "集采api")
@RestController
@RequestMapping("/commodity/procurement")
public class ProcurementApi {
    @Autowired
    private ProcurementService procurementService;

    /**
     * 所有集采
     * @param pageNo
     * @param pageSize
     * @return
     */
    @ApiOperation("所有集采")
    @ApiImplicitParams({
            @ApiImplicitParam(readOnly = true, name = "pageNo", value = "页面页数"),
            @ApiImplicitParam(readOnly = true, name = "pageSize", value = "页面数据量"),
            @ApiImplicitParam(readOnly = true, name = "userId", value = "用户Id"),
    })
    @GetMapping("/findList")
    public ResponseJson<PageInfo<ProcurementDto>> findList(int pageNo, int pageSize, Integer userId,Integer status) {
        return  procurementService.findList(pageNo, pageSize,userId, status);
    }

    /**
     * 查看集采详情
     * @param id
     * @return
     */
    @ApiOperation("查看集采详情")
    @ApiImplicitParams({
            @ApiImplicitParam(readOnly = true, name = "id", value = "集采Id"),
            @ApiImplicitParam(readOnly = true, name = "userId", value = "用户Id")
    })
    @GetMapping("/detail")
    public ResponseJson<Map<String,Object>> detailProcurement(String id, Integer userId) {
        if (null == id) {
            return ResponseJson.error(-1,"参数id不能为空", null);
        }
        if (null == userId) {
            return ResponseJson.error(-1,"userId不能为空", null);
        }
        return procurementService.detailProcurement(id, userId);
    }

//    /**
//     * 我参与的 | 我创建的
//     * @param userId
//     * @param procurementType 0 我参与的 1 我发起的
//     * @return
//     */
//    @ApiOperation("我参与的 | 我创建的")
//    @ApiImplicitParams({
//            @ApiImplicitParam(readOnly = true, name = "userId", value = "用户Id"),
//            @ApiImplicitParam(readOnly = true, name = "procurementType", value = "接口类型 0 我参与的 1 我发起的"),
//    })
//    @GetMapping("/procurement")
//    public ResponseJson<List<ProcurementDto>> myProcurement(Integer userId, Integer procurementType) {
//        if (null == userId) {
//            return ResponseJson.error(-1,"参数userId不能为空", null);
//        }
//        if (null == procurementType) {
//            return ResponseJson.error(-1,"参数集采类型不能为空", null);
//        }
//        return procurementService.myProcurement(userId, procurementType);
//    }

    /**
     * 修改集采信息回显
     * @param id
     * @param userId
     * @param procurementType 0 我参与的 1 我发起的
     * @return
     */
    @ApiOperation("修改集采信息回显")
    @ApiImplicitParams({
            @ApiImplicitParam(readOnly = true, name = "id", value = "集采id"),
            @ApiImplicitParam(readOnly = true, name = "userId", value = "用户Id"),
            @ApiImplicitParam(readOnly = true, name = "procurementType", value = "接口类型 0 我参与的 1 我发起的"),
    })
    @GetMapping("/editData")
    public ResponseJson<ProcurementDto> editData(String id, Integer userId, Integer procurementType) {
        if (null == id) {
            return ResponseJson.error(-1,"参数集采id不能为空", null);
        }
        if (null == userId) {
            return ResponseJson.error(-1,"参数userId不能为空", null);
        }
        if (null == procurementType) {
            return ResponseJson.error(-1,"参数集采类型不能为空", null);
        }
        return procurementService.editData(id, userId, procurementType);
    }

    /**
     * 发布集采 | 修改集采
     * @param procurementDto
     * @return
     */
    @ApiOperation("发布集采 | 修改集采")
    @ApiImplicitParams({
            @ApiImplicitParam(readOnly = true, name = "userId", value = "用户Id"),
            @ApiImplicitParam(readOnly = true, name = "productImage", value = "商品图片"),
            @ApiImplicitParam(readOnly = true, name = "productName", value = "商品名称"),
            @ApiImplicitParam(readOnly = true, name = "price", value = "期望单价"),
            @ApiImplicitParam(readOnly = true, name = "number", value = "购买数量")
    })
    @PostMapping("/saveProcurement")
    public ResponseJson saveProcurement(ProcurementDto procurementDto) throws Exception{
        if (null == procurementDto.getUserId()) {
            return ResponseJson.error(-1,"参数userId不能为空", null);
        }
        return procurementService.saveProcurement(procurementDto);
    }

    /**
     * 参与集采
     * @param procurementDto
     * @return
     */
    @ApiOperation("参与集采")
    @ApiImplicitParams({
            @ApiImplicitParam(readOnly = true, name = "userId", value = "用户Id"),
            @ApiImplicitParam(readOnly = true, name = "productImage", value = "商品图片"),
            @ApiImplicitParam(readOnly = true, name = "productName", value = "商品名称"),
            @ApiImplicitParam(readOnly = true, name = "price", value = "期望单价"),
            @ApiImplicitParam(readOnly = true, name = "number", value = "购买数量"),
            @ApiImplicitParam(readOnly = true, name = "status", value = "0参与1修改参与")
    })
    @PostMapping("/pateProcurement")
    public ResponseJson participateProcurement(ProcurementDto procurementDto,Integer status) throws Exception {
        if (null == procurementDto.getUserId()) {
            return ResponseJson.error(-1,"参数userId不能为空", null);
        }
        return procurementService.participateProcurement(procurementDto, status);
    }

    /**
     * 删除集采 | 退出集采
     * @param id
     * @param userId
     * @param procurementType
     * @return
     */
    @ApiOperation("删除集采 | 退出集采")
    @ApiImplicitParams({
            @ApiImplicitParam(readOnly = true, name = "id", value = "集采id"),
            @ApiImplicitParam(readOnly = true, name = "userId", value = "用户Id"),
            @ApiImplicitParam(readOnly = true, name = "procurementType", value = "接口类型 0 我参与的 1 我发起的")
    })
    @GetMapping("/updateProcurement")
    public ResponseJson updateProcurement(String id, Integer userId, Integer procurementType) {
        if (null == id) {
            return ResponseJson.error(-1,"集采id不能为空", null);
        }
        if (null == userId) {
            return ResponseJson.error(-1,"userId不能为空", null);
        }
        if (null == procurementType) {
            return ResponseJson.error(-1,"类型不能为空", null);
        }
        return procurementService.updateProcurement(id, userId, procurementType);
    }
}
