package com.caimei365.commodity.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.caimei365.commodity.annotation.IpSave;
import com.caimei365.commodity.annotation.Statistics;
import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.po.AnnouncementPo;
import com.caimei365.commodity.model.po.ProductParameterPo;
import com.caimei365.commodity.model.po.ProductPo;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.vo.*;
import com.caimei365.commodity.service.PageService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang.StringUtils;
import org.springframework.web.bind.annotation.*;

import java.sql.Timestamp;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/12
 */
@Api(tags = "商品页面数据API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/commodity")
public class ProductPageApi {

    private final PageService pageService;

    @ApiOperation("删除sku")
    @ApiImplicitParam(required = true, name = "skuId", value = "skuId")
    @GetMapping("/del/sku")
    public ResponseJson delSku(Integer skuId) {
        return pageService.delSku(skuId);
    }

    /**
     * 获取分类列表
     *
     * @param typeSort 分类类型：1产品，2仪器
     * @param source   请求来源：www,crm
     */
    @ApiOperation("获取分类菜单（旧：/product/classify）")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "typeSort", value = "分类类型：1产品，2仪器，0全部"),
            @ApiImplicitParam(required = false, name = "source", value = "请求来源：www,crm"),
            @ApiImplicitParam(required = false, name = "mallType", value = "商城类型：1采美，2呵呵")
    })
    @GetMapping("/classify")
    public ResponseJson<List<BigTypeVo>> getClassify(Integer typeSort, String source, Integer mallType) {
        return pageService.getClassify(typeSort, source, mallType);
    }

    /**
     * 产品/仪器页面数据
     *
     * @param pageId 页面信息id
     * @param userId 用户id
     * @param source 来源：1网站，2小程序
     */
    @ApiOperation("产品/仪器页面数据（旧：/home/instrumentData）")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "pageId", value = "页面信息id"),
            @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
            @ApiImplicitParam(required = false, name = "source", value = "来源：1网站，2小程序")
    })
    @GetMapping("/classify/product")
    public ResponseJson<Map<String, Object>> getClassifyData(Integer pageId, Integer userId, Integer source) {
        if (pageId == null) {
            return ResponseJson.error("参数异常", null);
        }
        return pageService.getClassifyData(pageId, userId, source);
    }

    /**
     * 首页楼层数据
     *
     * @param userId 用户id
     * @param source 来源 : 1 网站 ; 2 小程序
     */
    @ApiOperation("首页楼层数据(旧：/home/data)")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
            @ApiImplicitParam(required = false, name = "source", value = "来源：1网站，2小程序")
    })
    @IpSave(saveName = "首页楼层", saveParams = true)
    @GetMapping("/home/floor")
    public ResponseJson<Map<String, Object>> getHomeData(Integer userId, Integer source) {
        return pageService.getHomeData(userId, source);
    }


    @ApiOperation("新品橱窗重点推荐数据")
    @GetMapping("/home/recommend")
    public ResponseJson<List<ProductPo>> getNewFloorRecommend() {

        return pageService.getNewFloorRecommend();
    }

    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "brandID", value = "品牌id"),

    })
    @ApiOperation("新品橱窗列表")
    @IpSave(saveName = "新品橱窗商品列表", saveParams = false)
    @GetMapping("/home/NewFloorList")
    public ResponseJson<PaginationVo<ProductItemVo>> getNewFloorList(Integer source,
                                                                     Integer userId,
                                                                     @RequestParam(value = "brandID", required = false) List<String> brandID,
                                                                     @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                     @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {

        return pageService.getNewFloorList(source, userId, brandID, pageNum, pageSize);
    }

    @ApiOperation("新品橱窗品牌查询")
    @GetMapping("/home/BrandName")
    public ResponseJson<List<BrandVo>> getNewFloorBrand() {

        return pageService.getNewFloorBrand();
    }

    /**
     * 首页基础数据（小程序）
     *
     * @param source 来源 : 1 网站 ; 2 小程序
     */
    @ApiOperation("首页楼层数据(旧：/home/init)")
    @ApiImplicitParam(required = false, name = "source", value = "来源：1网站，2小程序")
    @GetMapping("/home/init")
    public ResponseJson<Map<String, Object>> getHomeInit(Integer source) {
        return pageService.getHomeInit(source);
    }

    @ApiOperation("公告展示列表")
    @ApiImplicitParam(required = false, name = "source", value = "来源：1网站，2小程序")
    @GetMapping("/home/title")
    ResponseJson<PaginationVo<AnnouncementPo>> getannlist(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                          @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return pageService.getannlist(pageNum, pageSize);
    }

    @ApiOperation("公告展示内容页面")
    @GetMapping("/home/capacity")
    public ResponseJson<AnnouncementPo> getcapacity(Integer id) {
        if (id == null || id == 0) {
            return ResponseJson.error("参数异常", null);
        }
        return pageService.getcapacity(id);
    }

    @ApiOperation("根据id查自由页")
    @GetMapping("/home/free")
    public ResponseJson<CmPageVo> getFree(Integer id) {
        if (id == null || id == 0) {
            return ResponseJson.error("参数异常", null);
        }
        return pageService.getFree(id);
    }


    /**
     * 首页侧边栏数据（小程序）
     *
     * @param source 来源 : 1 网站 ; 2 小程序
     */
    @ApiOperation("首页侧边栏数据(旧：/home/top/data)")
    @ApiImplicitParam(required = false, name = "source", value = "来源：1网站，2小程序")
    @GetMapping("/home/sidebar")
    public ResponseJson<Map<String, Object>> getHomesideBar(Integer source) {
        return pageService.getHomesideBar(source);
    }

    /**
     * 售后无忧,购物须知
     */
    @ApiOperation("售后无忧,购物须知(旧：/home/afterSale")
    @GetMapping("/home/sale/tips")
    public ResponseJson<AfterSaleVo> getAfterSale() {
        return pageService.getAfterSale();
    }

    /**
     * 二级专题页楼层数据
     *
     * @param pageId 页面id
     * @param source 来源 : 1 网站 ; 2 小程序
     */
    @ApiOperation("二级专题页楼层数据(旧：/page/topic, /page/topic/info)")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "pageId", value = "页面id"),
            @ApiImplicitParam(required = false, name = "source", value = "来源：1网站，2小程序")
    })
    @GetMapping("/page/floor")
    public ResponseJson<Map<String, Object>> getPageFloors(Integer pageId, Integer source) {
        return pageService.getPageFloors(pageId, source);
    }

    /**
     * 活动专题楼层数据（美博会等）
     *
     * @param pageId 页面id
     * @param userId 用户id
     * @param source 来源 : 1 网站 ; 2 小程序
     */
    @ApiOperation("活动专题楼层数据（美博会）(旧：/home/activity/data)")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "pageId", value = "页面id"),
            @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
            @ApiImplicitParam(required = false, name = "source", value = "来源：1网站，2小程序")
    })
    @GetMapping("/page/beauty")
    public ResponseJson<Map<String, Object>> getPageBeautyData(Integer pageId, Integer userId, Integer source) {
        return pageService.getPageBeautyData(pageId, userId, source);
    }

    /**
     * 楼层详情
     *
     * @param floorId 楼层id
     * @param userId  用户id
     * @param source  来源 : 1 网站 ; 2 小程序
     */
    @ApiOperation("楼层详情(旧：/home/floorContentDetails)")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "floorId", value = "楼层id"),
            @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
            @ApiImplicitParam(required = false, name = "source", value = "来源：1网站，2小程序")
    })
    @GetMapping("/page/floor/details")
    public ResponseJson<Map<String, Object>> getPageFloorData(Integer floorId, Integer userId, Integer source) {
        return pageService.getPageFloorData(floorId, userId, source);
    }

    /**
     * 分页详情楼层详情
     *
     * @param centreId 分页详情楼层id
     * @param userId   用户id
     * @param source   来源 : 1 网站 ; 2 小程序
     */
    @ApiOperation("分页详情楼层详情(旧：/home/pageFloorDetails)")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "centreId", value = "分页详情楼层id"),
            @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
            @ApiImplicitParam(required = false, name = "source", value = "来源：1网站，2小程序")
    })
    @GetMapping("/page/floor/centre")
    public ResponseJson<Map<String, Object>> getPageCentreData(Integer centreId, Integer userId, Integer source) {
        return pageService.getPageCentreData(centreId, userId, source);
    }

    /**
     * 商品详情页
     *
     * @param productId 商品Id
     * @param userId    用户Id
     *                  Statistics统计存入Redis的hash => prefix + ":" + field + ":" + date("yyyyMMdd");
     */
    @ApiOperation("商品详情页(旧：/product/details)")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
            @ApiImplicitParam(required = false, name = "productId", value = "商品Id")
    })
    @IpSave(saveName = "商品详情", saveParams = true)
    @Statistics(prefix = "statistics_details", field = "productId")
    @GetMapping("/product/details")
    public ResponseJson<ProductDetailVo> getProductDetails(Integer productId, Integer userId) {
        return pageService.getProductDetails(productId, userId);
    }

    /**
     * 商品详情页 -- 组织
     *
     * @param productId 商品Id
     * @param userId    用户Id
     *                  Statistics统计存入Redis的hash => prefix + ":" + field + ":" + date("yyyyMMdd");
     */
    @ApiOperation("商品详情页(旧：/product/details)")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
            @ApiImplicitParam(required = false, name = "productId", value = "商品Id")
    })
    @GetMapping("/product/organizeDetails")
    public ResponseJson<ProductDetailVo> getProductOrganizeDetails(Integer productId, Integer userId) {
        return pageService.getProductOrganizeDetails(productId, userId);
    }
    /**
     * 再次购买商品列表
     *
     * @param userId 用户Id
     */
    @ApiOperation("再次购买商品列表（旧：/repeat/buyAgain）")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "userId", value = "用户Id"),
            @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
            @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/product/repeat")
    public ResponseJson<PaginationVo<ProductItemVo>> getBuyAgainProducts(Integer userId,
                                                                         @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                         @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        return pageService.getBuyAgainProducts(userId, pageNum, pageSize);
    }


    /**
     * 项目仪器详情页
     */
    @ApiOperation("项目仪器详情页（旧：/equipment/recommend）")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
            @ApiImplicitParam(required = false, name = "equipmentId", value = "项目仪器Id")
    })
    @GetMapping("/equipment/details")
    @ResponseBody
    public ResponseJson<PageDetailVo> getEquipmentDetails(Integer equipmentId, Integer userId) {
        return pageService.getEquipmentDetails(equipmentId, userId);
    }


    /**
     * 商品详情页-图片
     *
     * @param productId 商品Id
     */
    @ApiOperation("商品详情-图片(旧：/product/detail/images)")
    @ApiImplicitParam(required = false, name = "productId", value = "商品Id")
    @GetMapping("/product/detail/images")
    public ResponseJson<List<String>> getProductDetailImages(Integer productId) {
        return pageService.getProductDetailImages(productId);
    }

    /**
     * 商品详情页-相关参数
     *
     * @param productId 商品Id
     */
    @ApiOperation("商品详情-相关参数(旧：/product/detail/parameter)")
    @ApiImplicitParam(required = false, name = "productId", value = "商品Id")
    @GetMapping("/detail/params")
    public ResponseJson<List<ProductParameterPo>> getProductParameters(Integer productId) {
        return pageService.getProductParameters(productId);
    }

    /**
     * 商品详情页-相关推荐
     *
     * @param productId     商品Id
     * @param recommendType 相关推荐类型: 0自动选择, 1手动推荐
     * @param userId        用户Id
     */
    @ApiOperation("商品详情-相关推荐(旧：/product/detail/recommend)")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "productId", value = "商品Id"),
            @ApiImplicitParam(required = false, name = "recommendType", value = "相关推荐类型: 0自动选择, 1手动推荐"),
            @ApiImplicitParam(required = false, name = "userId", value = "用户id")
    })
    @GetMapping("/detail/recommend")
    public ResponseJson<List<ProductListVo>> getProductDetailRecommends(Integer productId, Integer recommendType, Integer userId) {
        return pageService.getProductDetailRecommends(productId, recommendType, userId);
    }

    /**
     * 商品维修（链接分享数据）
     *
     * @param code 维修code
     */
    @ApiOperation("商品维修（链接分享）")
    @ApiImplicitParam(required = true, name = "code", value = "维修code")
    @GetMapping("/product/repair")
    public ResponseJson<ProductRepairVo> getProductRepair(String code) {
        return pageService.getProductRepair(code);
    }


    /**
     * 商品资料列表
     */
    @ApiOperation("商品资料列表")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "keyword", value = "搜索关键词"),
            @ApiImplicitParam(required = false, name = "productType", value = "商品属性：1产品，2仪器"),
            @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
            @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @IpSave(saveName = "美业资料搜索", saveParams = true)
    @GetMapping("/product/archive")
    public ResponseJson<PaginationVo<ArchiveVo>> getProductArchive(String keyword, Integer productType,
                                                                   @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                   @RequestParam(value = "pageSize", defaultValue = "10") int pageSize,
                                                                   @RequestParam(value = "productFlag", defaultValue = "1") int productFlag,
                                                                   @RequestParam(value = "linkageFlag", defaultValue = "0") int linkageFlag) {
        return pageService.getProductArchive(keyword, productType, pageNum, pageSize);
    }

    /**
     * 商品资料详情
     */
    @ApiOperation("商品资料详情")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "archiveId", value = "资料id"),
            @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
    })
    @GetMapping("/product/archive/detail")
    public ResponseJson<ArchiveDetailVo> getArchiveDetail(Integer archiveId, Integer userId) {
        if (null == archiveId || null == userId) {
            return ResponseJson.error("参数错误", null);
        }
        return pageService.getArchiveDetail(archiveId, userId);
    }

    /**
     * 超级会员优惠商品页面
     *
     * @param userId 用户id
     * @param source 来源 : 1 网站 ; 2 小程序
     * @return
     */
    @ApiOperation("超级会员优惠商品页面")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "userId", value = "用户id"),
            @ApiImplicitParam(required = false, name = "source", value = "来源 : 1 网站 ; 2 小程序"),
            @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
            @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/svip/product/page")
    public ResponseJson<Map<String, Object>> getSvipProductPage(Integer userId, Integer source,
                                                                @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        if (null == userId || source == null) {
            return ResponseJson.error("参数错误", null);
        }
        return pageService.getSvipProductPage(userId, source, pageNum, pageSize);
    }

    /**
     * 充值商品详情
     */
    @ApiOperation("充值商品详情(旧：/product/rechargeGoods)")
    @ApiImplicitParam(required = false, name = "productId", value = "商品Id")
    @GetMapping("/recharge/details")
    public ResponseJson<ProductDetailVo> getRechargeGoods(Integer productId) {
        if (productId == null) {
            return ResponseJson.error("参数异常", null);
        }
        return pageService.getRechargeGoods(productId);
    }

    /**
     * 正品联盟商品详情
     */
    @ApiOperation("充值商品详情(旧：/product/auth/details)")
    @ApiImplicitParam(required = false, name = "productId", value = "正品联盟商品Id")
    @GetMapping("/auth/details")
    public ResponseJson<AuthProductVo> getAuthProductDetails(Integer productId) {
        if (null == productId) {
            return ResponseJson.error("参数异常", null);
        }
        return pageService.getAuthProductDetails(productId);
    }

    /**
     * 采美百科产品仪器页面数据
     */
    @ApiOperation("采美百科产品仪器页面数据")
    @ApiImplicitParam(required = true, name = "commodityType", value = "商品类型：1产品，2仪器")
    @GetMapping("/baike/page")
    public ResponseJson<List<BaikeTypeVo>> getBaikePageData(Integer commodityType) {
        if (null == commodityType) {
            return ResponseJson.error("参数异常", null);
        }
        return pageService.getBaikePageData(commodityType);
    }

    /**
     * 采美百科产品仪器分类数据
     */
    @ApiOperation("采美百科产品仪器分类数据")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "typeId", value = "分类id"),
            @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
            @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量"),
    })
    @GetMapping("/baike/type")
    public ResponseJson<PaginationVo<BaikeProductVo>> getBaikeTypeData(Integer typeId,
                                                                       @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                       @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        if (null == typeId) {
            return ResponseJson.error("参数异常", null);
        }
        return pageService.getBaikeTypeData(typeId, pageNum, pageSize);
    }
//-----------------------------------------------1.3.3采美百科词条----------------------------------------------------------------------------------------

    /**
     * @param id           词条id
     * @param entryName    词条名称
     * @param typeId       分类id
     * @param auditStatus  审核状态
     * @param onlineStatus 上线状态
     * @param status       状态
     * @param pageNum      页数
     * @param pageSize     条数
     * @return
     */
    @GetMapping("/get/authuser/list")
    public ResponseJson<PaginationVo<BaikeProductVo>> getAuthUserList(Integer id, String name, Integer typeId, Integer auditStatus, Integer onlineStatus, Integer status, Integer shopId, @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                      @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        BaikeProductVo baikeProductVo = new BaikeProductVo();
        baikeProductVo.setProductId(id);
        baikeProductVo.setName(name);
        baikeProductVo.setTypeId(typeId);
        baikeProductVo.setAuditStatus(auditStatus);
        baikeProductVo.setOnlineStatus(onlineStatus);
        baikeProductVo.setStatus(status);
        baikeProductVo.setShopId(shopId);
        return pageService.getAuthUserList(baikeProductVo, pageNum, pageSize);
    }

    /**
     * 修改状态  0保存草稿箱  1已发布
     *
     * @param id
     * @return
     */
    @GetMapping("/up/entry/status")
    public ResponseJson upEntryStatusById(Integer id, Integer status) {
        return pageService.upEntryStatusById(id, status);
    }

    /**
     * 根据id删除词条
     *
     * @param id
     * @return
     */
    @GetMapping("/del/entry")
    public ResponseJson delEntryStatusById(Integer id) {
        return pageService.delEntryStatusById(id);
    }

    /**
     * 根据id查询详细信息
     *
     * @param id
     * @return
     */
    @GetMapping("/get/entry/info/by/id")
    public ResponseJson<BaikeProductVo> getEntryInfoById(Integer id) {
        return pageService.getEntryInfoById(id);
    }

    /**
     * 根据id删除资料
     *
     * @param id
     * @return
     */
    @GetMapping("/del/Reference")
    public ResponseJson delReferenceById(Integer id) {
        return pageService.delReferenceById(id);
    }

    /**
     * 根据id查询资料
     *
     * @param id
     * @return
     */
    @GetMapping("/get/Reference")
    public ResponseJson<CmBaikeReferenceInfo> getReferenceById(Integer id) {
        return pageService.getReferenceById(id);
    }

    /**
     * 保存资料
     *
     * @param params
     * @return
     */
    @PostMapping("/save/referenceInfo")
    public ResponseJson saveReferenceInfoByid(@RequestBody String params) {
        JSONObject paramsMap = JSONObject.parseObject(params);
        Integer id = paramsMap.getInteger("id");
        Integer referenceType = paramsMap.getInteger("referenceType");
        String website = paramsMap.getString("website");
        String articleName = paramsMap.getString("articleName");
        String publishTimeStr = paramsMap.getString("publishTimeStr");
        String acitationTimeStr = paramsMap.getString("acitationTimeStr");
        String author = paramsMap.getString("author");
        String workName = paramsMap.getString("workName");
        String publicationPlace = paramsMap.getString("publicationPlace");
        String press = paramsMap.getString("press");
        String publicationYearStr = paramsMap.getString("publicationYearStr");
        String acitationWeb = paramsMap.getString("acitationWeb");
        String referenceDescription = paramsMap.getString("referenceDescription");
        String imageDescription = paramsMap.getString("imageDescription");
        String imageUrl = paramsMap.getString("imageUrl");
        Integer entryId = paramsMap.getInteger("entryId");
        String entryType = paramsMap.getString("entryType");
        String ctrlId = paramsMap.getString("ctrlId");
        CmBaikeReferenceInfo cmBaikeReferenceInfo = new CmBaikeReferenceInfo();
        cmBaikeReferenceInfo.setId(id);
        cmBaikeReferenceInfo.setReferenceType(referenceType);
        cmBaikeReferenceInfo.setWebsite(website);
        cmBaikeReferenceInfo.setArticleName(articleName);
        cmBaikeReferenceInfo.setPublishTimeStr(publishTimeStr);
        cmBaikeReferenceInfo.setAcitationTimeStr(acitationTimeStr);
        cmBaikeReferenceInfo.setAuthor(author);
        cmBaikeReferenceInfo.setWorkName(workName);
        cmBaikeReferenceInfo.setPublicationPlace(publicationPlace);
        cmBaikeReferenceInfo.setPress(press);
        cmBaikeReferenceInfo.setPublicationYearStr(publicationYearStr);
        cmBaikeReferenceInfo.setAcitationWeb(acitationWeb);
        cmBaikeReferenceInfo.setReferenceDescription(referenceDescription);
        cmBaikeReferenceInfo.setImageDescription(imageDescription);
        cmBaikeReferenceInfo.setImageUrl(imageUrl);
        cmBaikeReferenceInfo.setEntryId(entryId);
        cmBaikeReferenceInfo.setEntryType(entryType);
        cmBaikeReferenceInfo.setCtrlId(ctrlId);
        if (null != cmBaikeReferenceInfo.getId()) {
            return pageService.upReferenceInfoByid(cmBaikeReferenceInfo);
        } else {
            return pageService.insertReferenceInfo(cmBaikeReferenceInfo);
        }
    }

    /**
     * 获取分类下来列表
     *
     * @return
     */
    @GetMapping("/get/type/list")
    public ResponseJson<List<BaikeTypeVo>> geTypeList() {
        return pageService.geTypeList();
    }

    /**
     * 保存词条详细信息
     *
     * @return
     */
    @PostMapping("/save/entry/info")
    public ResponseJson saveEntryInfo(BaikeProductVo baikeProductVo) {
        //json转集合对象 概述图册
        String imgListStr = baikeProductVo.getImageListStr();
        List<BaikeImageVo> baikeImageVos = JSONArray.parseArray(imgListStr, BaikeImageVo.class);
        baikeProductVo.setImageList(baikeImageVos);
        //json转集合对象 信息栏
        String infoListStr = baikeProductVo.getInfoListStr();
        List<BaikeInfoVo> infoList = JSONArray.parseArray(infoListStr, BaikeInfoVo.class);
        baikeProductVo.setInfoList(infoList);
        //json转集合对象 正文
        String textlistStr = baikeProductVo.getTextInfoListStr();
        List<BaikeTextInfoVo> textlist = JSONArray.parseArray(textlistStr, BaikeTextInfoVo.class);
        baikeProductVo.setTextInfoList(textlist);
        //json转集合对象 参考资料
        String referenceListStr = baikeProductVo.getReferenceListStr();
        List<CmBaikeReferenceInfo> referenceList = JSONArray.parseArray(referenceListStr, CmBaikeReferenceInfo.class);
        baikeProductVo.setReferenceList(referenceList);
        //json转集合对象 视频
        String videoListStr = baikeProductVo.getVideoListStr();
        List<BaikeVideoVo> videoList = JSONArray.parseArray(videoListStr, BaikeVideoVo.class);
        baikeProductVo.setVideoList(videoList);
        if (null != baikeProductVo && null != baikeProductVo.getId()) {
            //编辑
            return pageService.upEntryInfo(baikeProductVo);
        } else {
            //新增
            return pageService.insertEntryInfo(baikeProductVo);
        }
    }

}
