package com.caimei365.commodity.controller;

import com.caimei365.commodity.annotation.IpSave;
import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.vo.ProductItemVo;
import com.caimei365.commodity.model.vo.ImageLinkVo;
import com.caimei365.commodity.model.vo.PromotionsVo;
import com.caimei365.commodity.service.PromotionsService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 促销活动API
 *
 * @author : Charles
 * @date : 2021/4/9
 */
@Api(tags="促销活动API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/commodity/promotions")
public class PromotionsApi {
    private final PromotionsService promotionsService;
    /**
     * 专题活动列表数据
     *
     * @param source 来源
     */
    @ApiOperation("专题活动列表数据（旧：/promotions/list）")
    @ApiImplicitParams({
        @ApiImplicitParam(required = false, name = "source", value = "来源"),
        @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
        @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @IpSave(saveName = "获取专题活动列表",saveParams = true)
    @GetMapping("/list")
    public ResponseJson<PageInfo<ImageLinkVo>> getPromotionsList(Integer source,
                                                                 @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                 @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return promotionsService.getPromotionsList(source, pageNum, pageSize);
    }

    /**
     * 获取促销活动详情
     *
     * @param promotionsId 促销活动Id
     */
    @ApiOperation("获取促销活动详情（旧：/product/promotion/info）")
    @ApiImplicitParam(required = true, name = "promotionsId", value = "促销活动Id")
    @IpSave(saveName = "获取专题活动详情",saveParams = true)
    @GetMapping("/info")
    public ResponseJson<PromotionsVo> promotionDetails(Integer promotionsId) {
        if (null == promotionsId) {
            return ResponseJson.error("参数异常", null);
        }
        return promotionsService.getPromotionDetails(promotionsId);
    }

    /**
     * 获取促销活动凑单商品
     *
     * @param promotionsId 促销活动Id
     * @param identity     用户身份
     */
    @ApiOperation("获取促销活动凑单商品（旧：/product/promotion/products）")
    @ApiImplicitParams({
        @ApiImplicitParam(required = true, name = "promotionsId", value = "促销活动Id"),
        @ApiImplicitParam(required = false, name = "identity", value = "用户身份: 0个人，1协销，2会员机构，3供应商，4普通机构，5医美机构"),
        @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
        @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/product")
    public ResponseJson<PageInfo<ProductListVo>> promotionProduct(Integer promotionsId,
                                                               @RequestParam(value = "identity", defaultValue = "0") Integer identity,
                                                               @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                               @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        if (null == promotionsId) {
            return ResponseJson.error("参数异常", null);
        }
        return promotionsService.getPromotionProduct(promotionsId, identity, pageNum, pageSize);
    }

    /**
     * 获取赠品
     *
     * @param promotionsId 促销活动Id
     */
    @ApiOperation("获取赠品（旧：/product/promotion/gifts）")
    @ApiImplicitParam(required = true, name = "promotionsId", value = "促销活动Id")
    @GetMapping("/gifts")
    public ResponseJson<List<ProductItemVo>> getPromotionGifts(Integer promotionsId) {
        if (null == promotionsId) {
            return ResponseJson.error("参数异常", null);
        }
        return promotionsService.getPromotionGifts(promotionsId);
    }
}
