package com.caimei365.commodity.controller;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.vo.PaginationVo;
import com.caimei365.commodity.model.vo.ProductItemVo;
import com.caimei365.commodity.service.UserLikeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;


/**
 * @author zzj 2021/9/17
 *    测试
 */
@Api(tags = "用户收藏API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/commodity/userLike")
public class UserLikeApi {

    private final UserLikeService userLikeService;

    /**
     * 商品收藏（单个商品）
     */
    @ApiOperation("单个商品收藏/取消收藏")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "userID", value = "当前用户id"),
            @ApiImplicitParam(required = true, name = "productID", value = "收藏商品id"),
    })
    @GetMapping("/likeOne")
    public ResponseJson<String> like(Integer userId, Integer productId) {
        if (userId == null || productId == null) {
            return ResponseJson.error("非法参数");
        }
        return userLikeService.likeOne(userId, productId);
    }

    /**
     * 个人中心收藏商品列表
     *
     * @param userId 用户Id
     */
    @ApiOperation("收藏商品列表")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "userId", value = "用户Id"),
            @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
            @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/likeList")
    public ResponseJson<PaginationVo<ProductItemVo>> likes(Integer userId,
                                                           @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                           @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        if (userId == null) {
            return ResponseJson.error("非法参数");
        }
        return userLikeService.findLikeList(userId, pageNum, pageSize);
    }

    /**
     * 个人中心删除收藏商品列表
     *
     * @param userId 用户Id
     */
    @ApiOperation("删除收藏商品列表")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "userId", value = "用户Id"),
            @ApiImplicitParam(required = true, name = "productIDs", value = "商品id字符串")
    })
    @GetMapping("/deleteList")
    public ResponseJson<String> likes(Integer userId, String productIds) {
        if (userId == null || productIds == null) {
            return ResponseJson.error("非法参数");
        }
        return userLikeService.deleteList(userId, productIds);
    }


}
