package com.caimei365.commodity.mapper;

import com.caimei365.commodity.model.po.CouponClubPo;
import com.caimei365.commodity.model.po.CouponRedemptionCodePo;
import com.caimei365.commodity.model.vo.ActivityCouponVo;
import com.caimei365.commodity.model.vo.CouponVo;
import com.caimei365.commodity.model.vo.ProductItemVo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.Date;
import java.util.List;

/**
 * Description
 *
 * @author : plf
 * @date : 2021/8/12
 */
@Mapper
public interface CouponMapper {
    /**
     * 查询用户优惠券
     *
     * @param userId 机构用户id
     * @param status 使用状态: 1未使用 2已使用 3已失效
     * @return
     */
    List<CouponVo> findCouponClub(@Param("userId") Integer userId, @Param("status") Integer status);

    /**
     * 查询活动券详情
     *
     * @param couponId 优惠券id
     * @return
     */
    ActivityCouponVo findCouponById(Integer couponId);

    /**
     * 查询优惠券对应商品
     *
     * @param couponId 优惠券id
     * @param source   来源 : 1 小程序 ; 2 网站
     * @return
     */
    List<ProductItemVo> findCouponProduct(@Param("couponId") Integer couponId, @Param("source") Integer source, @Param("identity") Integer identity);

    /**
     * 查询可以领取的券
     *
     * @param userId
     * @return
     */
    List<CouponVo> findCouponList(@Param("userId") Integer userId, @Param("registerTime") Date registerTime);

    /**
     * 查询优惠券信息
     *
     * @param couponId
     * @param registerTime
     * @return
     */
    CouponVo getCoupons(@Param("couponId") Integer couponId, @Param("registerTime") Date registerTime);

    /**
     * 查询兑换码是否有效
     *
     * @param redemptionCode 兑换码
     * @return
     */
    CouponRedemptionCodePo findCouponRedemptionCode(String redemptionCode);

    /**
     * 查询用户是否已经领取优惠券
     *
     * @param userId   机构用户id
     * @param couponId 优惠券id
     * @return
     */
    Integer findCouponClubByUserId(@Param("userId") Integer userId, @Param("couponId") Integer couponId);

    /**
     * 保存领取优惠券记录
     *
     * @param couponClub
     */
    void insertCouponClub(CouponClubPo couponClub);

    /**
     * 更新兑换状态
     *
     * @param id           兑换码id
     * @param clubCouponId 用户关联优惠券id
     */
    void updateRedemptionCode(@Param("id") Integer id, @Param("clubCouponId") Integer clubCouponId);

    /**
     * 查询机构用户的注册时间
     *
     * @param userId
     * @return
     */
    Date findUserRegisterTime(Integer userId);

    Integer findVip(Integer userId);

    /**
     * 查所有超级会员优惠券
     * @return
     */
    List<Integer> findVipCoupon();

    List<CouponVo> findMoneyCoupons(@Param("userId") Integer userId, @Param("registerTime") Date registerTime);

    CouponVo findCouponDetail(Integer couponId);

    Integer findUserPermission(Integer userId);
}
