package com.caimei365.commodity.mapper;

import com.caimei365.commodity.model.po.ArchiveFilePo;
import com.caimei365.commodity.model.po.ArchivePo;
import com.caimei365.commodity.model.po.BrandProductParamPo;
import com.caimei365.commodity.model.po.ProductPo;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.vo.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/12
 */
@Mapper
public interface PageMapper {
    /**
     * 查询页面信息
     *
     * @param pageId 页面Id
     */
    Integer getPageTypeSort(Integer pageId);

    /**
     * 查询页面内容标签
     *
     * @param pageId
     * @return
     */
    String getPageLabel(Integer pageId);

    /**
     * 查询热搜词(单个页面)
     *
     * @param pageId
     */
    List<HotSearchVo> getHotSearchByPageId(Integer pageId, Integer source);

    /**
     * 查询热搜词（多个页面Id）
     *
     * @param pageIds
     */
    List<HotSearchVo> getHotSearchByPageIds(@Param("pageIds") List<Integer> pageIds, @Param("source") Integer source);

    /**
     * 首页楼层
     *
     * @param source
     */
    List<PageFloorVo> getHomePageFloor(Integer source);

    /**
     * 首页固定楼层
     *
     * @param source
     */
    List<PageFloorVo> getPageFloor(Integer source);

    /**
     * 查询页面信息商品楼层
     *
     * @param pageId
     */
    List<PageFloorVo> getFloorByPageId(Integer pageId, Integer source);

    /**
     * 查询楼层内容
     *
     * @param id 页面id
     */
    FloorContentVo getFloorContentById(Integer id);

    /**
     * 查询楼层相关图片
     *
     * @param id     页面id
     * @param source
     */
    List<FloorImageVo> getFloorImageById(Integer id, Integer source);

    /**
     * 查询楼层内容
     *
     * @param id 楼层id
     */
    FloorContentVo getFloorContentByCentreId(Integer id);

    /**
     * 查询楼层相关图片
     *
     * @param id     楼层id
     * @param source
     */
    List<FloorImageVo> getFloorImageByCentreId(Integer id, Integer source, Integer limitNum);

    /**
     * 获取商品及价格
     *
     * @param productId
     */
    ProductItemVo getProductItemById(Integer productId);

    /**
     * 优质供应商楼层
     */
    ShopFloorVo getSupplierFloorImage();

    /**
     * 查询优质供应商数据
     *
     * @param source
     */
    List<ShopImageVo> getSupplierImage(Integer source);

    /**
     * 获取用户组织
     * @param userId
     * @return
     */
    Integer getOrganizeId(@Param("userId") Integer userId);

    /**
     * 商品详情页
     */
    ProductDetailVo getProductDetails(Integer productId);

    /**
     * 商品详情页 组织
     * @param productId
     * @return
     */
    ProductDetailVo getProductOrganizeDetails(Integer productId);

    /**
     * 再次购买
     *
     * @param userId 用户Id
     */
    List<ProductItemVo> getBuyAgainProducts(Integer userId);

    /**
     * 页面详情
     *
     * @param id
     * @param type 类型：1二级列表 2项目详情 3讲师列表 4自由页面
     */
    PageDetailVo getPageDetails(Integer id, Integer type);

    /**
     * 根据仪器id和类型id获取仪器参数
     */
    List<EquipmentParameterVo> getEquipmentParametersByType(Integer equipmentId, Integer typeId);

    /**
     * 二级专题楼层下的数据
     */
    List<ImageLinkVo> getImageLinkByFloorId(Integer floorId);

    /**
     * 详情-相关推荐
     */
    List<ProductListVo> getProductRecommendsById(Integer productId);

    List<ProductListVo> getAutoProductRecommends(Integer productId);

    /**
     * 页面数据
     */
    CmPageVo findCmPageById(Integer pageId);

    /**
     * 获取搜索热门关键字
     */
    List<String> getSearchKeyword();

    /**
     * 获取头部菜单
     */
    List<TopMenuVo> getTopMenus(@Param("type") Integer type,@Param("source")Integer source);

    /**
     * 获取底部链接分类
     */
    List<BaseLinkVo> getHelpPageTypes();

    /**
     * 根据分类获取底部链接
     */
    List<BaseLinkVo> getHelpPagesByType(@Param("typeId") Integer typeId);

    /**
     * 获取友情链接
     */
    List<BaseLinkVo> getFriendLinks();

    /**
     * 仪器维修表ID
     */
    Integer getMaintenanceIdByCode(String code);

    /**
     * 维修详情
     */
    ProductRepairVo getMaintenanceById(Integer id);

    /**
     * 查询所有有效的优惠券
     *
     * @param userId
     * @param registerTime
     * @return
     */
    List<CouponVo> findAllCoupon(@Param("userId") Integer userId, @Param("registerTime") Date registerTime);

    /**
     * 查询所有优惠券指定商品id
     *
     * @param couponId 优惠券id
     * @param source   来源: 1小程序 2pc商城
     * @return
     */
    List<Integer> findAllProductId(@Param("couponId") Integer couponId, @Param("source") Integer source);

    /**
     * 查询商品资料列表
     *
     * @param keyword     搜索关键词
     * @param productType 商品属性：1产品，2仪器
     * @return
     */
    List<ArchiveVo> getProductArchiveList(@Param("keyword") String keyword, @Param("productType") Integer productType);

    /**
     * 获取图片资料列表
     *
     * @param archiveId 商品资料id
     * @return
     */
    List<ArchiveContentVo> getImageArchiveList(Integer archiveId);

    /**
     * 获取视频资料列表
     *
     * @param archiveId 商品资料id
     * @return
     */
    List<ArchiveContentVo> getVideoArchiveList(Integer archiveId);

    /**
     * 获取文件资料列表
     *
     * @param archiveId 商品资料id
     * @return
     */
    List<ArchiveContentVo> getFileArchiveList(Integer archiveId);

    /**
     * 获取图片资料图片列表
     *
     * @param archiveContentId 资料内容id
     * @return
     */
    List<String> getArchiveImageList(Integer archiveContentId);

    /**
     * 获取商品资料文件
     *
     * @param archiveContentId 资料内容id
     * @return
     */
    ArchiveFilePo getArchiveFile(Integer archiveContentId);

    /**
     * 获取商品资料信息
     *
     * @param archiveId 商品资料id
     * @return
     */
    ArchivePo getArchiveByArchiveId(Integer archiveId);

    /**
     * 获取关键词
     * @param ids
     * @return
     */
    List<String> keyWordList(ArrayList<String> ids);

    /**
     * 获取机构类型
     *
     * @param userId 用户id
     * @return
     */
    Integer getClubTypeByUserId(Integer userId);

    /**
     * 根据商品id获取资料id
     *
     * @param productId 商品id
     * @return
     */
    Integer getArchiveIdById(Integer productId);

    /**
     * 查询商品资料抵扣采美豆记录
     *
     * @param userId
     * @param archiveId
     * @return
     */
    Integer findBeansHistoryByArchiveId(Integer userId, Integer archiveId);

    /**
     * 查询超级会员优惠商品宣传图
     *
     * @param userId 用户id
     * @param source 来源 : 1 网站 ; 2 小程序
     * @return
     */
    String getSvipProductAdsImage(@Param("userId") Integer userId, @Param("source") Integer source);

    /**
     * 查询超级会员优惠商品列表
     *
     * @return
     */
    List<ProductItemVo> getSvipProductList();

    /**
     * 查询超级会员用户id
     *
     * @param userId 用户id
     * @return
     */
    Integer getSvipUserIdByUserId(Integer userId);

    /**
     * banner图
     */
    List<ImageLinkVo> getBannerImages();

    /**
     * 售后无忧,购物须知
     */
    AfterSaleVo getAfterSale();

    /**
     * 查询产品,仪器页面信息
     */
    List<Integer> getPageIdByTypeSort(Integer typeSort);

    /**
     * 查询首页置顶直播信息
     */
    List<LiveVo> getSidebarLive(Integer source);

    /**
     * 查询首页置顶文章信息
     */
    List<InfoVo> getSidebarInfo();

    /**
     * 查询首页置顶活动
     */
    List<PageImageVo> getSidebarPageImage(Integer source);

    /**
     * 查询首页直播宣传图
     */
    String getLiveAdvertisingImage();

    /**
     * 查询正品联盟商品详情
     */
    AuthProductVo getAuthProductByProductId(Integer productId);

    /**
     * 查询正品联盟声明文件
     */
    StatementFileVo getStatementFile(Integer authUserId, Integer brandId);

    /**
     * 查询正品联盟商品参数
     */
    List<BrandProductParamPo> getAuthProductParams(Integer productId);

    /**
     * 查询首页置顶百科
     */
    List<BaikeProductVo> getSidebarBaike();

    /**
     * 查询采美百科分类列表
     */
    List<BaikeTypeVo> getBaikeTypeList(Integer commodityType);

    /**
     * 根据百科分类id和关键词查询对应商品
     *
     * @param typeId
     * @param keyword
     * @param limitNum
     */
    List<BaikeProductVo> getBaikeProducts(@Param("typeId") Integer typeId, @Param("keyword") String keyword, @Param("limitNum") Integer limitNum);

    /**
     * 根据商品id查询问题列表
     */
    List<String> getBaikeQuestionList(Integer productId);

    /**
     * 查找呵呵首页页面
     */
    CmPageVo findHeheHomePage();

    /**
     * 新品橱窗重点推荐
     */
    List<ProductPo> getNewFloorRecommend();

    /**
     * 新品橱窗商品列表
     */
    List<ProductItemVo> getNewFloorList(@Param("brandID") List<String> brandID, @Param("status") Integer status);

    ProductItemVo getNewFloor(Integer productID);

    List<BrandVo> getNewFloorBrand();

    String findLink(Integer productId);

    void delSku(Integer skuId);

    List<BaikeProductVo> getAuthUserList(BaikeProductVo baikeProductVo);

    void upEntryStatusById(Integer id, Integer status, Date publishTime);

    void delEntryStatusById(Integer id);

    BaikeProductVo getEntryInfoById(Integer id);

    List<BaikeImageVo> getImageListById(Integer id);

    List<BaikeInfoVo> getInfoListById(Integer id);

    List<BaikeTextInfoVo> getTextInfoListById(Integer id);


    List<CmBaikeReferenceInfo> getReferenceListById(Integer id);

    List<BaikeTypeVo> geTypeList();

    List<BaikeVideoVo> getVideoListById(Integer id);

    void delReferenceById(Integer id);

    CmBaikeReferenceInfo getReferenceById(Integer id);

    void upReferenceInfoByid(CmBaikeReferenceInfo cmBaikeReferenceInfo);

    void insertReferenceInfo(CmBaikeReferenceInfo cmBaikeReferenceInfo);

    void upEntryInfo(BaikeProductVo cmBaikeReferenceInfo);

    void insertEntryInfo(BaikeProductVo cmBaikeReferenceInfo);

    void delImageListByEntryId(Integer id);

    void delVideoListByEntryId(Integer id);

    void delInfoListByEntryId(Integer id);

    void delTextListByEntryId(Integer id);

    void delreferenceByEntryId(Integer id);

    void insertImage(BaikeImageVo baikeImageVo);

    void insertVideo(BaikeVideoVo baikeVideoVo);

    void insertInfo(BaikeInfoVo baikeInfoVo);

    void insertText(BaikeTextInfoVo baikeInfoVo);

    void insertreference(CmBaikeReferenceInfo baikeInfoVo);

    Integer getShopid(Integer authUserId);

    String getHelpContent(Integer helpId);

    List<String> findLabels(String labelIds);

    String findKeyWordId(String labelId);
}
