package com.caimei365.commodity.mapper;

import com.caimei365.commodity.model.dto.Sku;
import com.caimei365.commodity.model.dto.VipSkuPriceDto;
import com.caimei365.commodity.model.vo.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/9
 */
@Mapper
public interface PriceMapper {
    /**
     * 根据用户Id查询用户身份
     */
    Integer getIdentityByUserId(Integer userId);
    /**
     * 根据商品id查找价格
     */
    PriceVo getDetailPrice(Integer productId);

    /**
     * 采美sku最低价
     * @param productId
     * @return
     */
    PriceVo getMinPrice(Integer productId);

    /**
     * 外部商城sku最低价
     * @param productId
     * @return
     */
    PriceVo getOrganizeMinPrice(Integer productId);
    /**
     * 根据商品Id查找组织商品价格
     * @param productId
     * @return
     */
    List<Sku> getDetailOrganizePrice(Integer productId);
    /**
     * 根据商品id集合查找 价格列表
     */
    List<PriceVo> getListPriceByProductIds(@Param("productIds") List<Integer> productIds);
    /**
     * 根据skuId查询阶梯价列表
     */
    List<LadderPriceVo> getLadderPricesByProductId(Integer skuId);
    /**
     * 获取最低阶梯价（价格最低，阶梯数最大）
     */
    LadderPriceVo findLowerLadderPrice(Integer skuId);
    /**
     * 获取最高阶梯价（价格最高，阶梯数最小）
     */
    LadderPriceVo findMaxLadderPrice(Integer skuId);
    /**
     * 根据商品ID和用户ID 查询复购价
     */
    Double getRepurchasePrice(@Param("skuId") Integer skuId, @Param("userId") Integer userId);
    /**
     * 根据商品ID含税和发票信息
     */
    TaxVo getTaxByProductId(Integer productId);
    /**
     * 根据用户id查询超级会员用户id
     */
    Integer getSvipUserIdByUserId(Integer userId);
    /**
     * 获取商品销量信息
     */
    ProductSalesVo getProductSalesInfo(Integer productId);

    void insertProductSales(ProductSalesVo salesVo);

    void updateProductSales(ProductSalesVo salesVo);
    /**
     * 会员机构类型：1医美，2生美
     */
    Integer getClubTypeById(Integer userId);
    /**
     * 根据用户Id查询供应商Id
     */
    Integer getShopIdByUserId(Integer userId);

    /**
     * 组织Id
     * @param userId
     * @return
     */
    Integer getOrganize(Integer userId);
    /**
     * 添加销量记录
     * @param productId 商品Id
     * @param sales 销量
     */
    void insertProductSalesRecord(Integer productId, Integer sales);

    /**
     * skus
     * @param productId
     * @return
     */
    List<Sku> findSkus(Integer productId);

    /**
     * skus
     * @param productId
     * @return
     */
    List<Sku> findOrganizeProductSkus(Integer productId);

    /**
     * 外部商城sku
     * @param productId
     * @return
     */
    List<MallProductSkuVo> findOrganizeSkus(Integer productId);

    /**
     * 查找所有阶梯价中最低价
     * @param productId
     * @return
     */
    ProductItemVo findLowPrice(Integer productId);

    Integer getSaleOutFlag(Integer productId);

    List<Sku> findSkusOutOfPrice(Integer productId);

    ProductItemVo findLowPriceOfAll(Integer productId);

    ProductItemVo findLowPriceOfPrice(Integer productId);

    VipSkuPriceDto getVipSku(Integer skuId);

    Double getTouchPriceBySku(Integer skuId,Integer promotionId);
}
