package com.caimei365.commodity.mapper;

import com.caimei365.commodity.model.dto.Sku;
import com.caimei365.commodity.model.po.*;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.vo.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/16
 */
@Mapper
public interface ShopMapper {
    /**
     * 供应商-主推商品
     */
    List<ProductListVo> getMainProducts(Integer shopId, List<Integer> visibilityList);

    /**
     * 上架费过期数量
     */
    Integer listingfeeExpire(Integer shopID);

    /**
     * 上架费数量
     */
    Integer listingFee(Integer shopID);
    /**
     * 是否有免除上架费
     */
    Integer receStatct(Integer shopID);
    /**
     * 主推商品数量
     */
    int getMainProductsCount(Integer shopId);

    /**
     * 获取供应商-我的商品列表
     */
    List<ProductItemVo> getShopProductsSelect(Integer showFlag, Integer newvalidFlag, Integer shopId, String name, String productCode, Integer validFlag, Integer featuredFlag, Integer commodityType, Integer bigTypeId, Integer smallTypeId, Integer tinyTypeId, Integer groundMall);

    /**
     * 列表显示分类
     */
    String getTypeName(Integer bigTypeId, Integer smallTypeId, Integer tinyTypeId);

    /**
     * 根据供应商Id获取userId
     */
    Integer getUserIdByshopId(Integer shopId);

    /**
     * 根据分类获取商品货号
     */
    String getCodeByTypeId(Integer bigTypeId, Integer smallTypeId, Integer tinyTypeId);

    /**
     * 发布商品
     */
    void insertProduct(ProductPo product);

    /**
     * 编辑商品
     */
    void updateProduct(ProductPo product);
    /**
     * 商品状态
     * @param organizeId
     * @param productId
     * @param validFlag
     */
    void insertVaildFlag(@Param("organizeId") Integer organizeId,@Param("productId") Integer productId,@Param("validFlag") Integer validFlag);

    /**
     * 修改商品状态
     * @param organizeId
     * @param productId
     * @param validFlag
     */
    void updateVaildFlag(@Param("organizeId") Integer organizeId,@Param("productId") Integer productId,@Param("validFlag") Integer validFlag);

    /**
     * 获取商品图片
     */
    List<ProductImagePo> getImageByProductId(Integer productId);

    /**
     * 新增商品图片
     */
    void insertProductImage(ProductImagePo productImage);

    /**
     * 更新商品图片
     */
    void updateProductImage(ProductImagePo productImage);

    /**
     * 删除商品图片
     */
    void deleteProductImage(Integer id);

    /**
     * 删除相关参数
     */
    void deleteProductParameters(Integer productId);

    /**
     * 保存相关参数
     */
    void insertProductParameters(ProductParameterPo parameters);

    /**
     * 保存商品详情
     */
    void insertProductDetailInfo(ProductDetailInfoPo productDetail);

    /**
     * 修改商品详情
     */
    void updateProductDetailInfo(ProductDetailInfoPo productDetail);

    /**
     * 供应商-商品编辑回显
     */
    ProductFormVo getProductForm(Integer productId);

    /**
     * 获取品牌名称
     */
    String getBrandNameById(Integer brandId);

    /**
     * 获取相关参数
     */
    List<ProductParameterPo> getProductParameters(Integer productId);

    /**
     * 获取商品图片
     */
    List<ProductImagePo> getProductImages(Integer productId);

    /**
     * 获取商品详情
     */
    ProductDetailInfoPo getProductDetailInfo(Integer productId);

    /**
     * 商品详情--组织
     * @param productId
     * @return
     */
    ProductDetailInfoPo getProductOrganizeDetailInfo(Integer productId);

    /**
     * 供应商信息
     */
    ShopVo getProductShopById(Integer shopId);

    /**
     * 上架商品数量
     */
    Integer getProductNumById(Integer shopId);

    /**
     * 获取用户身份
     */
    Integer getUserIdentityById(Integer userId);

    /**
     * 供应商-商品编辑-品牌联想
     */
    List<BrandVo> getBrandAssociation(Integer userId, String name);

    /**
     * 供应商-商品编辑-品牌检测
     */
    BrandVo getBrandByName(String name);

    /**
     * 供应商-提交新品牌
     */
    void insertBrand(BrandPo brand);

    /**
     * 供应商-更新品牌
     */
    void updateBrand(BrandPo brand);

    /**
     * 供应商-品牌管理
     */
    List<BrandVo> getShopBrandList(String name, Integer status, Integer userId);

    /**
     * 供应商-添加,删除主页推荐
     */
    int updateProductFeatured(Integer productId, Integer shopId, Integer featuredFlag);

    /**
     * 供应商-下架商品
     */
    void updateProductValidFlag(@Param("productId") Integer productId,@Param("validFlag") Integer validFlag,@Param("organizeId") Integer organizeId);

    /**
     * 供应商-更新商品编码
     */
    void updateProductCode(String productCode, Integer productId);

    /**
     * 获取商品pc云上美博会活动状态
     */
    Integer getPcBeautyStatusById(Integer productId);

    /**
     * 获取商品小程序云上美博会活动状态
     */
    Integer getAppletsBeautyStatusById(Integer productId);

    /**
     * 获取供应商名称
     */
    String getShopNameByShopId(Integer shopId);

    void insertSku(Sku s);

    void updateSku(Sku s);

    /**
     * 删除Sku
     * @param skuIds
     * @param productId
     */
    void deleteSku(List<Integer> skuIds, Integer productId, Integer organizeId);

    void insertProductInfo(@Param("organizeId") Integer organizeId, @Param("productId") Integer productId, @Param("validFlag") Integer validFlag);
}
