package com.caimei365.commodity.model.po;

import com.caimei365.commodity.model.dto.Sku;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/16
 */
@Data
public class ProductPo implements Serializable {
    private static final long serialVersionUID = 1L;
    /**
     * 商品productID
     */
    private Integer productId;
    /**
     * 上架商城
     */
    private String groundMall;
    /**
     * 品牌Id
     */
    private Integer brandId;
    /**
     * 商品名称
     */
    private String name;
    /**
     * 价格可见度：0公开价格 1不公开价格 2仅对会员机构公开 price1TextFlag
     */
    private Integer priceFlag;
    /**
     * 商品货号
     */
    private String productCode;
    /**
     * 内部商品名称
     */
    private String aliasName;
    /**
     * 搜索关键词,4个用英文逗号区分,不存在的直接逗号隔空(顺序参考:品牌,学名,市场称呼,大类别,小类别)
     */
    private String searchKey;
    /**
     * 销售区域：1全部区域， 0指定区域
     */
    private String allAreaFlag;
    /**
     * 指定的销售区域
     */
    private String provinceIds;
    /**
     * 主图
     */
    private String mainImage;
    /**
     * 商品属性：1产品，2仪器
     */
    private Integer commodityType;
    /**
     * 一级分类id
     */
    private Integer bigTypeId;
    /**
     * 二级分类id
     */
    private Integer smallTypeId;
    /**
     * 三级分类Id
     */
    private Integer tinyTypeId;
    /**
     * 商品的类别：1正常商品(默认)，2二手商品
     */
    private Integer productCategory;
    /**
     * 常用商品001，精品推荐010，热门推荐100，三者同时存在111
     */
    private Integer preferredFlag;
    /**
     * 所属供应商Id
     */
    private Integer shopId;
    /**
     * 销量
     */
    private Integer sellNumber;
    /**
     * 成本价选中标志：1固定成本 2比例成
     */
    private Integer costCheckFlag;
    /**
     * 比例成本百分比
     */
    private Double costProportional;
    /**
     * 是否有sku：1有， 0没有
     */
    private Integer hasSkuFlag;
    /**
     * 商品状态， 0逻辑删除 1待审核 2已上架 3已下架 8审核未通过 9已隐身 10已冻结
     */
    private Integer validFlag;
    /**
     * 启用阶梯价格标识 0否 1是
     */
    private Integer ladderPriceFlag;
    /**
     * 排序值
     */
    private Integer sortIndex;
    /**
     * 供应商主推商品标志 0否 1是
     */
    private Integer featuredFlag;
    /**
     * 运费：0买家承担， 1卖家承担
     */
    private Integer byFlag;
    /**
     * 购买数量: 1逐步增长,2以起订量增长(起订量的倍数增长)
     */
    private Integer step;
    /**
     * 是否使用活动角标：1是，空或0不是[与actType搭配使用,仅用于标识非真正活动]
     */
    private Integer actFlag;
    /**
     * 商品是否处于活动状态：1是，空或0不是[活动商品和actFlag含义不同]
     */
    private Integer actStatus;
    /**
     * 是否包邮 0包邮 1到付
     */
    private Integer freePostFlag;
    /**
     * 商品类型：0其它类型(默认)，1妆字号，2械字号
     */
    private Integer productType;
    /**
     * 械字号类型   (基于械字号基础),1：一类，2：二类，3：三类
     */
    private Integer machineType;
    /**
     * 械字号资质证书图  (基于械字号基础)
     */
    private String qualificationImg;
    /**
     * 开票税点(基于不含税基础) :增值税默认13%，普通票6%取值范围[0-100]
     */
    private Double taxPoint;
    /**
     * 是否含税   0不含税，1含税，2未知
     */
    private Integer includedTax;
    /**
     * 商品标签用英文逗号隔开，中文逗号或其它一律不作切割
     */
    private String tags;
    /**
     * 服务起订量
     */
    private Integer serviceNumber;
    /**
     * 供应商税率:增值专用发票默认13%，增值税普通发票6%取值范围[0-100]
     */
    private Double supplierTaxPoint;
    /**
     * 相关推荐类型 0自动选择; 1手动推荐
     */
    private Integer recommendType;
    /**
     * 发票类型(基于是否含税基础)   1增值税票，2普通票, 3不能开票
     */
    private Integer invoiceType;
    /**
     * 商品可见度：（3:所有人可见，2:普通机构可见，1:会员机构可见）
     */
    private Integer visibility;

    /**
     * 商品详情可见度
     */
    private Integer commodityDetailsFlag;
    /**
     * 添加时间
     */
    private String addTime;
    /**
     * 更新时间
     */
    private String updateTime;
    /**
     * 上架时间
     */
    private Date onlineTime;
    /**
     * 下架时间
     */
    private Date offlineTime;
    /**
     * 仪器培训方式：1线上培训，2线下培训
     */
    private Integer trainingMethod;
    /**
     * 售价是否包含：1售价未包含，2售价已包含
     */
    private Integer trainingType;
    /**
     * 培训费用(售价未包含)
     */
    private BigDecimal trainingFee;
    /**
     * 发布类型 1.二手预成交商品 2.二手估价商品
     */
    private Integer announType;
    /**
     * 新品商品状态  0.参与 ， 1.审核通过， 2.未参与 ，3.审核未通过'
     */
    private Integer newvalidFlag;
    /**
     * 新品参与状态：1.参与2.未参与
     */
    private Integer newProductType;
    /**
     * 新品展示状态1,已展示2,已下线3,展示过期
     */
    private Integer showFlag;
    /**
     * 展示结束时间
     */
    private String showTime;
    /**
     * 重点推荐1，重点
     */
    private Integer recommend;
    /**
     * 展示开始时间
     */
    private String newshowTime;

    private String BrandName;

    /**
     * 证书编号
     * @return
     */
    public String qualificationNo;

    /**
     *产品名称
     */
    public String productName;
    /*
     *证书有效日期
     */
    public String qualificationTime;

    /**
     *证书有效链接
     */
    public String qualificationLink;

    /**
     * 库存skus
     */
    public List<Sku> skus;
}
