package com.caimei365.commodity.model.vo;

import com.caimei365.commodity.model.dto.Sku;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

/**
 * 顶部购物车数据
 *
 * @author : Charles
 * @date : 2021/4/9
 */
@Data
public class ProductItemVo implements Serializable {
    private static final long serialVersionUID = 1L;

    private Integer stock;
    /**
     * 展示的sku的价格等级
     */
    private Integer priceGrade;
    /**
     * 组合商品列表默认的起订量
     */
    private Integer minBuyNumber;
    /**
     * 展示的sku的skuId
     */
    private Integer skuId;
    /**
     * skus
     */
    private List<Sku> skus;
    /**
     * 赠品skuId
     */
    private Integer giftSkuId;
    /**
     * 再次购买中的成本
     */
    private Double costPrice;
    /**
     * 再次购买中的成本标记
     */
    private Integer costCheckFlag;
    /**
     * itemId
     */
    private Integer id;
    /**
     * 展示的最低价的规格
     */
    private String unit;
    /**
     * 展示的最低价
     */
    private Double price;
    /**
     * 默认的最低市场价（列表显示）
     */
    private Double normalPrice;
    /**
     * 商品productID
     */
    private Integer productId;

    private Integer brandID;
    /**
     * 名称name
     */
    private String name;
    /**
     * 主图mainImage
     */
    private String image;
    /**
     * 品牌
     */
    private String brandName;
    /**
     * 商品货号
     */
    private String code;
    /**
     * 是否公开机构价 0公开价格 1不公开价格
     */
    private Integer priceFlag;
    /**
     * 商品可见度：3:所有人可见，2:普通机构可见，1:会员机构可见，4:仅医美机构可见
     */
    private String visibility;
    /**
     * 所属供应商Id，关联供应商表
     */
    private Integer shopId;
    /**
     * 搜索关键词searchKey
     */
    private String keyword;
//    /**
//     * 美博会商品活动状态
//     */
//    private Integer beautyActFlag;
    /**
     * 商品原价
     */
    private Double originalPrice;
    /**
     * 购买数量
     */
    private Integer number;
    /**
     * 是否是赠品 2是，其他否
     */
    private Integer productType;
    /**
     * 增量
     */
    private Integer step;
    /**
     * 最大购买量
     */
    private Integer maxBuyNumber;
    /**
     * 商品上架状态：0逻辑删除 1待审核 2已上架 3已下架 8审核未通过 9已冻结
     */
    private Integer validFlag;
    /**
     * 联合丽格商品状态
     */
    private Integer mallValidFlag;
    /**
     * 活动状态：1有效，0失效
     */
    private Integer actStatus;
    /**
     * 购物车失效状态：0有效，1后台删除的，2冻结的，3下架，4售罄 >7库存不足，5价格仅会员可见，6未公开价格
     */
    private Integer status;
    /**
     * 促销活动
     */
    private PromotionsVo promotions;
    /**
     * 商品的类别：1正常商品(默认)，2二手商品
     */
    private Integer productCategory;
    /**
     * 商品货号
     */
    private String productCode;
    /**
     * 商品是否默认选中
     */
    private Boolean productsChecked = false;
    /**
     * 成本大于复购价 或 当前机构价小于复购价
     */
    private Boolean repurchasePriceState = false;
    /**
     * 是否含税 0不含税，1含税，2未知
     */
    private String includedTax;
    /**
     * 发票类型(基于是否含税基础) 1增值税票，2普通票, 3不能开票
     */
    private String invoiceType;
    /**
     * 机构税率
     */
    private BigDecimal taxRate;
    /**
     * 用户身份: 2-会员机构, 4-普通机构
     */
    private Integer userIdentity;
    /**
     * 是否启用详聊，1不开启，2开启(开启详聊不展示交易价)
     */
    private Integer detailTalkFlag;
    /**
     * 内部商品名称
     */
    private String aliasName;
    /**
     * 所在分类名称
     */
    private String typeName;
    /**
     * 供应商主推商品标志 0否 1是
     */
    private Integer featuredFlag;
    /**
     * 商品属性：1产品，2仪器
     */
    private Integer commodityType;
    /**
     * 一级分类ID
     */
    private Integer bigTypeId;
    /**
     * 二级分类Id
     */
    private Integer smallTypeId;
    /**
     * 三级分类Id
     */
    private Integer tinyTypeId;
    /**
     * 初始化商品数量0，提供前端使用(组合商品)
     */
    private Integer initProductNum;
    /**
     * 初始化商品总金额，提供前端使用(组合商品)
     */
    private Double totalPrice;
    /**
     * 再次购买价格
     */
    private Double discountPrice;
    /**
     * 判断是否勾选（前端使用）
     */
    private Boolean isChecked = false;

    /**
     * 优惠券标识是否显示
     */
    private Boolean couponsLogo = false;

    /**
     * 超级会员优惠商品标识：0不是，1是
     */
    private Integer svipProductFlag;

    /**
     * 超级会员优惠价标签
     */
    private String svipPriceTag;
    /**
     * 发布类型 1.二手预成交商品 2.二手估价商品
     */
    private Integer announType;
    /**
     * 新品商品状态  0.参与 ， 1.审核通过， 2.未参与 ，3.审核未通过'
     */
    private Integer newvalidFlag;
    /**
     * 新品展示状态1,已展示2,已下线3,展示过期
     */
    private Integer showFlag;
    /**
     * 展示结束时间
     */
    private String showTime;
    /**
     * 重点推荐1，重点
     */
    private Integer recommend;
    /**
     * 展示开始时间
     */
    private String newshowTime;
    /**
     * 新品参与状态1.参与2.未参与
     */
    private Integer newProductType;
    /**
     * 上架平台
     */
    private String groundMall;
    /**
     * 上架平台集合
     */
    private List<String> organizeNames;

    private String BrandName;

    /**
     * 楼层相关商品图片
     */
    private List<FloorImageVo> floorImageList;
    /**
     * 楼层相关商品图片2
     */
    private List<FloorImageVo> floorImageList2;
    /**
     * 楼层相关商品图片3
     */
    private List<FloorImageVo> floorImageList3;
    /**
     * 外部商城sku
     */
    private List<MallProductSkuVo> organizeSkus;
}
