package com.caimei365.commodity.service;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.dto.CollarCouponsDto;
import com.caimei365.commodity.model.dto.RedeemCouponsDto;
import com.caimei365.commodity.model.vo.CouponVo;
import com.github.pagehelper.PageInfo;

import java.text.ParseException;
import java.util.Map;

/**
 * Description
 *
 * @author : plf
 * @date : 2021/8/12
 */
public interface CouponService {
    /**
     * 已领取优惠券中心
     *
     * @param userId   机构用户id
     * @param status   使用状态: 1未使用 2已使用 3已失效
     * @param pageNum  页码
     * @param pageSize 每页数量
     * @return
     */
    ResponseJson<PageInfo<CouponVo>> couponCenter(Integer userId, Integer status, int pageNum, int pageSize);

    /**
     * 活动券部分商品活动数据
     *
     * @param couponId 活动券id
     * @param userId   机构用户id
     * @param source   来源: 1小程序 2pc商城
     * @param pageNum  页码
     * @param pageSize 每页数量
     * @return
     */
    ResponseJson<Map<String, Object>> activityPage(Integer couponId, Integer userId, Integer source, int pageNum, int pageSize);

    /**
     * 领券中心
     *
     * @param userId   机构用户id
     * @param pageNum  页码
     * @param pageSize 每页数量
     * @return
     */
    ResponseJson<PageInfo<CouponVo>> collarCouponsList(Integer userId, int pageNum, int pageSize);

    /**
     * 领取优惠券
     *
     * @param couponsDto
     * @return
     */
    ResponseJson<String> collarCoupons(CollarCouponsDto couponsDto) throws ParseException;

    /**
     * 兑换优惠券
     *
     * @param redeemCouponsDto
     * @return
     */
    ResponseJson<CouponVo> redeemCoupons(RedeemCouponsDto redeemCouponsDto);

    /**
     * 统计已领取优惠券数量
     *
     * @param userId 机构用户id
     * @return
     */
    ResponseJson<Map<String, Integer>> couponsCount(Integer userId);

    /**
     * 商品详情相关优惠券
     *
     * @param userId    机构用户id
     * @param productId 商品id
     * @param source    来源 : 1 小程序 ; 2 网站
     * @param status    状态: 1未领取 2已领取
     * @return
     */
    ResponseJson<Map<String, Object>> detailsCoupons(Integer userId, Integer productId, Integer source, Integer status);

    ResponseJson<PageInfo<CouponVo>> findMoneyCoupons(Integer userId,int pageNum, int pageSize);

    ResponseJson<CouponVo> findCouponDetail(Integer couponId);

    ResponseJson<PageInfo<CouponVo>> collarCenterList(Integer userId, int pageNum, int pageSize);
}
