package com.caimei365.commodity.service;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.po.AnnouncementPo;
import com.caimei365.commodity.model.po.ProductParameterPo;
import com.caimei365.commodity.model.po.ProductPo;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.vo.*;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/12
 */
public interface PageService {
    /**
     * 获取分类列表
     *  @param typeSort 分类类型：1产品，2仪器，0全部
     * @param source   请求来源：www,crm
     * @param mallType
     */
    ResponseJson<List<BigTypeVo>> getClassify(Integer typeSort, String source, Integer mallType);

    /**
     * 产品/仪器页面数据
     *
     * @param pageId 页面信息id
     * @param userId 用户id
     * @param source 来源：1网站，2小程序
     */
    ResponseJson<Map<String, Object>> getClassifyData(Integer pageId, Integer userId, Integer source);

    /**
     * 首页楼层数据
     *
     * @param userId 用户id
     * @param source 来源：1网站，2小程序
     */
    ResponseJson<Map<String, Object>> getHomeData(Integer userId, Integer source);


    /**
     * 首页基础数据（小程序）
     *
     * @param source 来源 : 1 网站 ; 2 小程序
     */
    ResponseJson<Map<String, Object>> getHomeInit(Integer source);

    /**
     * 首页侧边栏数据
     *
     * @param source 来源 : 1 网站 ; 2 小程序
     */
    ResponseJson<Map<String, Object>> getHomesideBar(Integer source);

    /**
     * 售后无忧,购物须知
     */
    ResponseJson<AfterSaleVo> getAfterSale();

    /**
     * 二级专题页楼层数据
     *
     * @param pageId 页面id
     * @param source 来源 : 1 网站 ; 2 小程序
     */
    ResponseJson<Map<String, Object>> getPageFloors(Integer pageId, Integer source);

    /**
     * 活动专题楼层数据（美博会等）
     *
     * @param pageId 页面id
     * @param userId 用户id
     * @param source 来源 : 1 网站 ; 2 小程序
     */
    ResponseJson<Map<String, Object>> getPageBeautyData(Integer pageId, Integer userId, Integer source);

    /**
     * 楼层详情
     *
     * @param floorId 楼层id
     * @param userId  用户id
     * @param source  来源 : 1 网站 ; 2 小程序
     */
    ResponseJson<Map<String, Object>> getPageFloorData(Integer floorId, Integer userId, Integer source);

    /**
     * 分页详情楼层详情
     *
     * @param centreId 分页详情楼层id
     * @param userId   用户id
     * @param source   来源 : 1 网站 ; 2 小程序
     */
    ResponseJson<Map<String, Object>> getPageCentreData(Integer centreId, Integer userId, Integer source);

    /**
     * 商品详情页
     *
     * @param productId 商品Id
     * @param userId    用户Id
     */
    ResponseJson<ProductDetailVo> getProductDetails(Integer productId, Integer userId);

    /**
     * 商品详情页 -- 组织
     * @param productId
     * @param userId
     * @return
     */
    ResponseJson<ProductDetailVo> getProductOrganizeDetails(Integer productId, Integer userId);

    /**
     * 再次购买商品列表
     *
     * @param userId 用户Id
     */
    ResponseJson<PaginationVo<ProductItemVo>> getBuyAgainProducts(Integer userId, int pageNum, int pageSize);

    /**
     * 项目仪器详情页
     *
     * @param equipmentId 项目仪器Id
     */
    ResponseJson<PageDetailVo> getEquipmentDetails(Integer equipmentId, Integer userId);

    /**
     * 商品详情页-图片
     *
     * @param productId 商品Id
     */
    ResponseJson<List<String>> getProductDetailImages(Integer productId);

    /**
     * 商品详情页-相关参数
     *
     * @param productId 商品Id
     */
    ResponseJson<List<ProductParameterPo>> getProductParameters(Integer productId);

    /**
     * 商品详情页-相关推荐
     *
     * @param productId     商品Id
     * @param recommendType 相关推荐类型: 0自动选择, 1手动推荐
     * @param userId        用户Id
     */
    ResponseJson<List<ProductListVo>> getProductDetailRecommends(Integer productId, Integer recommendType, Integer userId);
    //公告展示
    ResponseJson<PaginationVo<AnnouncementPo>> getannlist(int pageNum, int pageSize);

    /**
     * 公告展示-公告详细内容
     *
     * @param  id 公告列表Id
     */
    ResponseJson<AnnouncementPo> getcapacity(Integer id);


    /**
     * 商品维修（链接分享数据）
     *
     * @param code 维修code
     */
    ResponseJson<ProductRepairVo> getProductRepair(String code);

    /**
     * 优惠券标识是否显示
     *
     * @param userId    机构用户id
     * @param productId 商品id
     * @param source    来源 : 1 小程序 ; 2 网站
     * @return
     */
    Boolean setCouponsLogo(Integer userId, Integer productId, Integer source);

    /**
     * 商品资料列表
     *
     * @param keyword     搜索关键词
     * @param productType 商品属性：1产品，2仪器
     * @param pageNum     页码
     * @param pageSize    每页数量
     * @return
     */
    ResponseJson<PaginationVo<ArchiveVo>> getProductArchive(String keyword, Integer productType, Integer pageNum, Integer pageSize);

    /**
     * 商品资料详情
     *
     * @param archiveId 商品资料id
     * @param userId    用户id
     * @return
     */
    ResponseJson<ArchiveDetailVo> getArchiveDetail(Integer archiveId, Integer userId);

    /**
     * 超级会员优惠商品页面
     *
     * @param userId   用户id
     * @param source   来源 : 1 网站 ; 2 小程序
     * @param pageNum  页码
     * @param pageSize 每页数量
     * @return
     */
    ResponseJson<Map<String, Object>> getSvipProductPage(Integer userId, Integer source, Integer pageNum, Integer pageSize);

    /**
     * 充值商品详情
     * @param productId 商品id
     */
    ResponseJson<ProductDetailVo> getRechargeGoods(Integer productId);

    /**
     * 正品联盟商品详情
     * @param productId     正品联盟商品Id
     * @return
     */
    ResponseJson<AuthProductVo> getAuthProductDetails(Integer productId);

    /**
     * 采美百科产品仪器页面数据
     * @param commodityType 商品类型：1产品，2仪器
     */
    ResponseJson<List<BaikeTypeVo>> getBaikePageData(Integer commodityType);

    /**
     * 采美百科产品仪器分类数据
     *
     * @param typeId 分类id
     * @return
     */
    ResponseJson<PaginationVo<BaikeProductVo>> getBaikeTypeData(Integer typeId, int pageNum, int pageSize);

    ResponseJson<CmPageVo> getFree(Integer id);

    ResponseJson<List<ProductPo>>getNewFloorRecommend();

     ResponseJson <List<BrandVo>>getNewFloorBrand();

    ResponseJson<PaginationVo<ProductItemVo>> getNewFloorList(Integer source,Integer userId,List<String> brandID,int pageNum, int pageSize);


    /**
     * 设置跳转参数
     * @param floorContent
     */
    void setFloorLinkType(FloorContentVo floorContent);

    ResponseJson delSku(Integer skuId);
 //--------------------------------- 1.3.3采美百科词条----------------------------------------------------------------------------------------
    /**
     * 获取供应商词条信息
     * @param baikeProductVo
     * @param pageNum
     * @param pageSize
     * @return
     */
   ResponseJson<PaginationVo<BaikeProductVo>> getAuthUserList(BaikeProductVo baikeProductVo,Integer pageNum,Integer pageSize);

    /**
     * 修改状态  0保存草稿箱  1已发布
     * @param id
     * @return
     */
   ResponseJson upEntryStatusById(Integer id,Integer status);
    /**
     * 根据id删除词条
     * @param id
     * @return
     */
    ResponseJson delEntryStatusById(Integer id);

    /**
     * 根据id查询详细信息
     * @param id
     * @return
     */
    ResponseJson<BaikeProductVo> getEntryInfoById(Integer id);

    /**
     * 根据id删除资料
     * @param id
     * @return
     */
    ResponseJson delReferenceById(Integer id);

    /**
     * 根据id查询资料
     * @param id
     * @return
     */
    ResponseJson<CmBaikeReferenceInfo> getReferenceById(Integer id);

    /**
     * 更新资料
     * @param cmBaikeReferenceInfo
     * @return
     */
    ResponseJson upReferenceInfoByid(CmBaikeReferenceInfo cmBaikeReferenceInfo);

    /**
     * 新增资料
     * @param cmBaikeReferenceInfo
     * @return
     */
    ResponseJson insertReferenceInfo(CmBaikeReferenceInfo cmBaikeReferenceInfo);

    /**
     * 获取分类下来列表
     * @return
     */
    ResponseJson<List<BaikeTypeVo>> geTypeList();

    /**
     * 修改词条详细信息
     * @param baikeProductVo
     * @return
     */
    ResponseJson upEntryInfo(BaikeProductVo baikeProductVo);
    /**
     * 新增词条详细信息
     * @param baikeProductVo
     * @return
     */
    ResponseJson insertEntryInfo(BaikeProductVo baikeProductVo);

}
