package com.caimei365.commodity.service;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.po.SearchHistoryPo;
import com.caimei365.commodity.model.vo.SearchKeywordyVo;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/7
 */
public interface SearchProductService {
    /**
     * 根据关键词搜索商品
     *
     * @param keyword   搜索关键字
     * @param identity: 0个人，1协销，2会员机构，3供应商，4普通机构
     * @param pageNum   页码
     * @param pageSize  每页数量
     * @param sortField 排序字段
     * @param sortType  升降序0/1
     * @return JsonStr(list)
     */
    ResponseJson<String> queryProductByKeyword(String keyword, String brandIds, Integer identity, Integer newFlag, Integer promotionFlag, int pageNum, int pageSize, String sortField, Integer sortType);

    /**
     * 根据分类Id搜索商品
     *
     * @param id        bigTypeID/smallTypeID/tinyTypeID
     * @param idType    id类型：1一级分类，2二级分类，3三级分类
     * @param identity: 0个人，1协销，2会员机构，3供应商，4普通机构
     * @param pageNum   页码
     * @param pageSize  每页数量
     * @param sortField 排序字段
     * @param sortType  升降序0/1
     * @return JsonStr(list)
     */
    ResponseJson<String> queryProductByType(Integer id, Integer idType, String brandIds, Integer identity, Integer newFlag, Integer promotionFlag, int pageNum, int pageSize, String sortField, Integer sortType);

    /**
     * 根据小程序运营分类Id搜索商品
     *
     * @param id        运营级分类Id
     * @param identity  用户身份 1:协销， 2:会员机构
     * @param pageNum   页码
     * @param pageSize  每页数量
     * @param sortField 排序字段
     * @param sortType  升降序0/1
     * @return JsonStr(list)
     */
    ResponseJson<String> queryProductByClassify(Integer id, Integer identity, int pageNum, int pageSize, String sortField, Integer sortType);

    /**
     * 根据供应商Id搜索商品（商铺内搜索）
     *
     * @param id        供应商Id
     * @param keyword   搜索关键字
     * @param identity  用户身份 1:协销， 2:会员机构
     * @param pageNum   页码
     * @param pageSize  每页数量
     * @param sortField 排序字段
     * @param sortType  升降序0/1
     * @return JsonStr(list)
     */
    ResponseJson<String> querySupplierProduct(Integer id, String keyword, Integer identity, int pageNum, int pageSize, String sortField, Integer sortType);

    /**
     * 根据用户ID查找历史记录
     *
     * @param userId 用户Id
     */
    ResponseJson<List<SearchHistoryPo>> getSearchHistory(Integer userId);

    /**
     * 保存搜索历史记录
     *
     * @param userId  用户Id
     * @param keyword 搜索关键字
     */
    ResponseJson<Void> addSearchHistory(Integer userId, String keyword);

    /**
     * 根据用户ID删除历史记录
     *
     * @param userId 用户Id
     */
    ResponseJson<Void> deleteSearchHistory(Integer userId);

    /**
     * 产品仪器热搜词
     */
    ResponseJson<Map<String, Object>> getHotSearchTerms();

    ResponseJson<Set<HashMap<String, Object>>> queryBrand(String keyword, Integer id, Integer idType, Integer newFlag, Integer promotionFlag, Integer identity);

    /**
     * 统计关键词及次数
     *
     * @param fromType
     * @param path
     * @param keyword
     * @return
     */
    ResponseJson conKeyword(Integer fromType, String path, String keyword);

    /**
     * 获取已加入关键词库的关键词进行搜索联动
     * 从redis获取，获取不到则去数据库获取
     *
     * @return
     */
    List<SearchKeywordyVo> getKeywordList(String keyword);

    void conKeyWord();

    List<SearchKeywordyVo> getKeywordLIstByData(String keyword);
}
