package com.caimei365.commodity.service;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.dto.BrandDto;
import com.caimei365.commodity.model.dto.FeaturedDto;
import com.caimei365.commodity.model.dto.ProductDto;
import com.caimei365.commodity.model.po.BrandPo;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.vo.BrandVo;
import com.caimei365.commodity.model.vo.PaginationVo;
import com.caimei365.commodity.model.vo.ProductFormVo;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/16
 */
public interface ShopService {

    /**
     * 供应商-主推商品
     * @param shopId   供应商Id
     * @param identity 用户身份：1协销，2会员机构，3供应商，4普通机构
     * @return
     */
    ResponseJson<List<ProductListVo>> getMainProducts(Integer shopId, Integer identity);

    /**
     * 供应商-我的商品列表
     *
     * @param shopId        供应商Id
     * @param name          商品名称
     * @param productCode   货号
     * @param validFlag     状态：0逻辑删除，1待审核，2已上架，3已下架，8审核未通过，9已隐身，10已冻结
     * @param featuredFlag  是否主推：0否，1是
     * @param commodityType 商品属性：1产品，2仪器
     * @param bigTypeId     一级分类Id
     * @param smallTypeId   二级分类Id
     * @param tinyTypeId    三级级分类Id
     * @param groundMall    上架平台
     * @param pageNum       页码
     * @param pageSize      每页数量
     * @return PageInfo<ProductShopVO>
     */
    ResponseJson<Map<String, Object>> getShopProducts(Integer showFlag,Integer shopId, String name, String productCode, Integer validFlag, Integer featuredFlag, Integer commodityType, Integer bigTypeId, Integer smallTypeId, Integer tinyTypeId, Integer groundMall, Integer newvalidFlag, int pageNum, int pageSize);

    /**
     * 供应商-发布商品
     *
     * @param productDto {
     *                   aliasName	    内部商品名称
     *                   allAreaFlag	销售区域：1全部区域， 0指定区域
     *                   bigTypeId	    一级分类id
     *                   brandId	    品牌id
     *                   brandName	    品牌名称
     *                   commodityType	商品属性：1产品，2仪器
     *                   costPrice	    成本价
     *                   detailInfo	    商品详情信息
     *                   includedTax	是否含税：0不含税，1含税，2未知
     *                   invoiceType	发票类型
     *                   machineType	械字号类型
     *                   minBuyNumber	最小购买量
     *                   name	        商品名称
     *                   normalPrice	市场价
     *                   orderInfo	    订购方案
     *                   price	        机构价格
     *                   productCode	商品货号
     *                   productType	商品类型：0其它，1妆字号，2械字号
     *                   provinceIds	指定的销售区域
     *                   qualificationImg 械字号资质证书图
     *                   searchKey	      搜索关键词
     *                   serviceInfo	  服务详情
     *                   shopId	         供应商id
     *                   smallTypeId	 二级分类id
     *                   step	         购买数量
     *                   stock	         库存
     *                   tags	         商品标签，逗号隔开
     *                   taxPoint	     开票税点
     *                   tinyTypeId	     三级分类id
     *                   unit	         包装规格
     *                   }
     */
    ResponseJson releaseProduct(ProductDto productDto);

    /**
     * 供应商-商品编辑回显
     *
     * @param productId 商品Id
     */
    ResponseJson<ProductFormVo> getProductForm(Integer productId);

    /**
     * 供应商-商品编辑-品牌联想
     *
     * @param userId  用户Id
     * @param name    关键词
     */
    ResponseJson<List<BrandVo>> brandAssociation(Integer userId, String name);

    /**
     * 供应商-商品编辑-品牌检测
     *
     * @param name 品牌名称
     */
    ResponseJson<BrandVo> brandDetection(String name);

    /**
     * 供应商-提交新品牌
     *
     * @param brandDto {
     *                 name        品牌名字
     *                 source      添加来源 0:后台添加，1:供应商添加
     *                 userId      添加用户ID,后台则为后台用户ID,供应商则为供应商用户ID
     *                 logo        品牌logo
     *                 description 品牌描述
     * }
     */
    ResponseJson<BrandPo> addBrand(BrandDto brandDto);

    /**
     * 供应商-品牌管理
     *
     * @param name     品牌名称
     * @param status   品牌状态 0:待审核，1:审核通过，2:审核失败
     * @param userId   用户Id
     * @param pageNum  页码
     * @param pageSize 每页数量
     */
    ResponseJson<PaginationVo<BrandVo>> brandManagement(String name, Integer status, Integer userId, int pageNum, int pageSize);

    /**
     * 供应商-商品编辑-品牌联想
     *
     * @param featuredDto {
     *                    productId    商品Id
     *                    featuredFlag 供应商主推商品标志 0删除 1添加
     *                    shop         供应商Id
     *                    }
     */
    ResponseJson switchFeatured(FeaturedDto featuredDto);

    /**
     * 供应商-批量下架商品
     *
     * @param  productIds 商品id集合,以','隔开
     * @param  groundMallType 上架平台类型
     */
    ResponseJson soldOutProducts(String productIds, Integer groundMallType);
}
