package com.caimei365.commodity.service.impl;

import com.caimei365.commodity.mapper.AdditionalRepository;
import com.caimei365.commodity.model.po.AdditionalPo;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.data.mongodb.core.query.Update;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/4/26
 */
@Service
public class AdditionalService {

    @Resource
    private AdditionalRepository additionalRepository;
    @Resource
    private MongoTemplate mongoTemplate;

    /**
     * 保存
     *
     * @param additional
     */
    public void save(AdditionalPo additional) {
        //如果需要自定义主键，可以在这里指定主键；如果不指定主键，MongoDB会自动生成主键
        //设置一些默认初始值。。。
        //调用dao
        additionalRepository.save(additional);
    }

    /**
     * 修改
     *
     * @param additional
     */
    public void update(AdditionalPo additional) {
        Query query = Query.query(Criteria.where("_id").is(additional.getId()));
        Update update = Update.update("delFlag",additional.getDelFlag());
        //  更新一条数据
        mongoTemplate.updateFirst(query,update, AdditionalPo.class);
//        //调用dao
//        additionalRepository.save(additional);
    }

    /**
     * 根据id删除
     *
     * @param id
     */
    public void deleteById(String id) {
        //调用dao
        additionalRepository.deleteById(id);
    }

    /**
     * 根据条件删除
     *
     * @param additionalId
     */
    public void deleteByAdditionalId(String additionalId) {
        //调用dao
        Query query = new Query();
        query.addCriteria(Criteria.where("additionalId").is(additionalId));
        mongoTemplate.remove(query, AdditionalPo.class);
    }

    /**
     * 查询所有
     *
     * @return
     */
    public List<AdditionalPo> findList() {
        //调用dao
        return additionalRepository.findAll();
    }

    /**
     * 根据id查询
     *
     * @param id
     * @return
     */
    public AdditionalPo findById(String id) {
        //调用dao
        return additionalRepository.findById(id).get();
    }

    /**
     * 根据主集采Id查询
     *
     * @param procureId
     * @return
     */
    public List<AdditionalPo> findProcureById(String procureId) {
        //调用dao
        Query query = new Query();
        query.addCriteria(Criteria.where("procureId").is(procureId));
        query.addCriteria(Criteria.where("delFlag").is("0"));
        return mongoTemplate.find(query, AdditionalPo.class);
    }

    /**
     * 根据参与集采Id查询
     *
     * @param additionalId
     * @return
     */
    public AdditionalPo findAdditionalById(String additionalId) {
        //调用dao
        Query query = new Query();
        query.addCriteria(Criteria.where("additionalId").is(additionalId));
        query.addCriteria(Criteria.where("delFlag").is("0"));
        return mongoTemplate.find(query, AdditionalPo.class).get(0);
    }

}
