package com.caimei365.commodity.service.impl;

import com.caimei365.commodity.mapper.*;
import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.dto.HeHeSku;
import com.caimei365.commodity.model.dto.Sku;
import com.caimei365.commodity.model.po.*;
import com.caimei365.commodity.model.vo.*;
import com.caimei365.commodity.service.HeheService;
import com.caimei365.commodity.service.PageService;
import com.caimei365.commodity.utils.AppletsLinkUtil;
import com.caimei365.commodity.utils.ImageUtils;
import com.caimei365.commodity.utils.MathUtil;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.aspectj.weaver.ast.Var;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.*;


/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/9
 */
@Slf4j
@Service
public class HeheServiceImpl implements HeheService {
    @Value("${caimei.wwwDomain}")
    private String domain;
    @Resource
    private HeheMapper heheMapper;
    @Resource
    private SearchMapper searchMapper;
    @Resource
    private PageMapper pageMapper;
    @Resource
    private ShopMapper shopMapper;
    @Resource
    private SecondHandMapper secondHandMapper;


    @Override
    public ResponseJson<List<BigTypeVo>> getHomeTypeList() {
        List<BigTypeVo> homeTypeList = heheMapper.getHomeTypeList();
        return ResponseJson.success(homeTypeList);
    }

    @Override
    public ResponseJson<Map<String, Object>> getProductList(Integer listType, Integer homeTypeId, Integer homeFloorId, Integer smallTypeId, Integer couponId, Integer activityId, Integer userId, String name, String productIds, Integer sortType, int pageNum, int pageSize) {
        // 综合排序时排除掉已查询的商品id，始终取第一页的数据
        PageHelper.startPage(1 == sortType ? 1 : pageNum, pageSize);
        List<HeheProductVo> productList = heheMapper.getProductList(listType, homeTypeId, homeFloorId, smallTypeId, couponId, activityId, name, sortType, productIds);
        productList.forEach(product -> setProductInfo(product, userId));
        PaginationVo<HeheProductVo> page = new PaginationVo<>(productList);
        if (1 == listType) {
            // 保存搜索记录
            if (StringUtils.isNotEmpty(name) && userId != null && userId > 0) {
                //保存并删除大于10条的历史记录
                SearchHistoryPo historyRecord = new SearchHistoryPo();
                historyRecord.setUserId(userId);
                historyRecord.setSearchDate(new Date());
                historyRecord.setSearchWord(name);
                historyRecord.setDelFlag(0);
                Integer recordId = searchMapper.getHistoryIdByWord(name, userId);
                if (recordId != null && recordId > 0) {
                    //更新
                    historyRecord.setId(recordId);
                    searchMapper.updateSearchHistoryById(historyRecord);
                } else {
                    // 新增
                    searchMapper.insertSearchHistory(historyRecord);
                }
                int count = searchMapper.getHistoryCount(userId);
                if (count > 10) {
                    // 删除大于10条的历史记录
                    searchMapper.deleteSearchHistory(userId);
                }
            }
        }
        HashMap<String, Object> map = new HashMap<>();
        map.put("pageInfo", page);
        if (6 == listType) {
            String activityBanner = heheMapper.getActivityImageById(activityId);
            map.put("activityBanner", activityBanner);
        }
        return ResponseJson.success(map);
    }

    @Override
    public ResponseJson<Map<String, Object>> getHomeData(Integer userId) {
        // 页面数据
        CmPageVo page = pageMapper.findHeheHomePage();
        if (page == null) {
            return ResponseJson.error("首页页面不存在", null);
        }
        // 来源：小程序
        Integer source = 2;
        List<PageFloorVo> floorList = pageMapper.getFloorByPageId(page.getId(), source);
        ListIterator<PageFloorVo> iterator = floorList.listIterator();
        while (iterator.hasNext()) {
            PageFloorVo floor = iterator.next();
            FloorContentVo floorContent = pageMapper.getFloorContentByCentreId(floor.getId());
            if (null == floorContent) {
                iterator.remove();
            } else {
                setFloorLinkType(floorContent);
                Integer limitNum = 6;
                String templateType = floorContent.getTemplateType();
                if ("5".equals(templateType) || "9".equals(templateType)) {
                    limitNum = null;
                }
                List<FloorImageVo> floorImageList = pageMapper.getFloorImageByCentreId(floor.getId(), source, limitNum);
                setFloorImageProduct(userId, floorImageList);
                floor.setFloorImageList(floorImageList);
                floor.setFloorContent(floorContent);
            }
        }
        Map<String, Object> map = new HashMap<>(2);
        map.put("page", page);
        map.put("floorList", floorList);
        return ResponseJson.success(map);
    }

    @Override
    public ResponseJson<PaginationVo<HeHeActivityVo>> getActivityList(Integer userId, Integer pageNum, Integer pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<HeHeActivityVo> activityList = heheMapper.getActivityList(userId);
        PaginationVo<HeHeActivityVo> pageInfo = new PaginationVo<>(activityList);
        return ResponseJson.success(pageInfo);
    }

    @Override
    public ResponseJson<HeheProductVo> getProductDetails(Integer productId, Integer userId) {
        HeheProductVo product = heheMapper.getProduct(productId);
        if (product == null) {
            //商品不存在
            return ResponseJson.error("商品不存在", null);
        }else{
            //特殊商品需添加退货提示
            if(null!=product.getReturnGoodsStutas()&&product.getReturnGoodsStutas()==2){
                product.setHelpContent(heheMapper.getHelpContent(1040));
            }
        }
        String[] split = null;
        //商品标签
        if (product.getTags() != null) {
            String tags = product.getTags();
            tags = tags.replace(" ", ",").replace("、", ",").replace("，", ",");
            split = tags.split(",");
            List<String> list = new ArrayList<>();
            for (String s : split) {
                if (org.apache.commons.lang3.StringUtils.isNotBlank(s)) {
                    list.add(s);
                }
            }
            split = list.toArray(new String[list.size()]);
        }
        product.setTagsList(split);
        //商品图片
        List<String> imageList = secondHandMapper.getImageByProductId(product.getProductId());
        imageList.forEach(img -> img = ImageUtils.getImageURL("product", img, 0, domain));
        product.setImageList(imageList);
        //商品详情
        ProductDetailInfoPo productDetail = shopMapper.getProductDetailInfo(productId);
        product.setProductDetail(productDetail);
        //相关参数
        List<ProductParameterPo> parametersList = shopMapper.getProductParameters(productId);
        product.setParametersList(parametersList);
        setProductInfo(product, userId);
        return ResponseJson.success(product);
    }

    @Override
    public ResponseJson<List<HeHeImageVo>> getHomeCarousel() {
        List<HeHeImageVo> imageList = heheMapper.getHomeCarousel();
        return ResponseJson.success(imageList);
    }

    private void setProductInfo(HeheProductVo product, Integer userId) {
        product.setMainImage(ImageUtils.getImageURL("product", product.getMainImage(), 0, domain));
        //设置sku
        List<HeHeSku> heheSkus = heheMapper.findHeheSkus(product.getProductId());
        heheSkus.forEach(s -> setProductInfoBySku(product, userId, s));
        //选最低价作为展示
        heheSkus.sort(Comparator.comparing(HeHeSku::getPrice));
        //product设值
        product.setSkus(heheSkus);
        HeHeSku heHeSku = heheSkus.get(0);
        product.setPrice(heHeSku.getPrice());
        product.setSkuId(heHeSku.getSkuId());
        product.setActiveStatus(null != heHeSku.getActiveStatus() ? heHeSku.getActiveStatus() : null);
        product.setCollageStatus(null != heHeSku.getCollageStatus() ? heHeSku.getCollageStatus() : null);
        product.setCollageProduct(null != heHeSku.getCollageProduct() ? heHeSku.getCollageProduct() : null);
        product.setDiscountStatus(null != heHeSku.getDiscountStatus() ? heHeSku.getDiscountStatus() : null);
        product.setDiscountEndTime(null != heHeSku.getDiscountEndTime() ? heHeSku.getDiscountEndTime() : null);
        product.setCouponStatus(null != heHeSku.getCouponStatus() ? heHeSku.getCouponStatus() : null);
        product.setCouponPrice(null != heHeSku.getCouponPrice() ? heHeSku.getCouponPrice() : null);
        product.setNormalPrice(null != heHeSku.getNormalPrice() ? heHeSku.getNormalPrice() : null);
        product.setNormalCouponPrice(null != heHeSku.getNormalCouponPrice() ? heHeSku.getNormalCouponPrice() : null);
        product.setCouponId(null != heHeSku.getCouponId() ? heHeSku.getCouponId() : null);
        product.setCouponInfo(null != heHeSku.getCouponInfo() ? heHeSku.getCouponInfo() : null);
    }

    private void setProductInfoBySku(HeheProductVo product, Integer userId, HeHeSku sku) {
        // 活动id
        Integer activityId = heheMapper.getActivityIdByProductId(product.getProductId());
        // 拼团商品
        HeheCollageProductPo collageProduct = heheMapper.getCollageProduct(sku.getSkuId());
        // 限时特价
        HeheDiscountPricePo discountPrice = heheMapper.getDiscountPrice(sku.getSkuId());
        // 内部优惠折扣
        HeHeDiscountVo discount = heheMapper.getProductDiscount(product.getProductId(), userId);
        if (activityId != null && activityId > 0) {
            sku.setActiveStatus(1);
            //活动阶梯
            List<LadderPriceVo> ladderList = heheMapper.getActivityLadderList(activityId, sku.getSkuId());
            if (ladderList != null && ladderList.size() > 0) {
                LadderPriceVo ladder = ladderList.get(0);
                // 没有起订量概念，默认显示购买1个商品的价格，若第一阶梯为一个商品，则取第一阶梯价格
                sku.setPrice(1 == ladder.getBuyNum() ? new BigDecimal(ladder.getBuyPrice()) : product.getPrice());
            }
        } else if (collageProduct != null) {
            // 拼团价
            sku.setPrice(collageProduct.getPrice());
            sku.setCollageStatus(1);
            sku.setCollageProduct(collageProduct);
        } else if (discountPrice != null) {
            // 限时特价
            sku.setPrice(discountPrice.getDiscountPrice());
            sku.setDiscountStatus(1);
            sku.setDiscountEndTime(discountPrice.getOfflineTime());
        } else if (discount != null) {
            BigDecimal price = product.getPrice();
            // 折扣价
            BigDecimal disPrice = discount.getDiscountPrice();
            // 折扣率
            Integer dis = discount.getDiscount();
            if (null != disPrice && disPrice.compareTo(BigDecimal.ZERO) > 0) {
                price = disPrice;
            } else if (null != dis && dis > 0) {
                price = MathUtil.div(MathUtil.mul(product.getPrice(), dis), 100);
            }
            sku.setPrice(price);
        }
        //税费
        boolean addTaxFlag = ("0".equals(product.getIncludedTax()) && ("1".equals(product.getInvoiceType()) || "2".equals(product.getInvoiceType())));
        if (addTaxFlag) {
            // 售价税费
            BigDecimal addedValueTax = MathUtil.div(MathUtil.mul(sku.getPrice(), product.getClubTaxPoint()), BigDecimal.valueOf(100), 2);
            BigDecimal price = MathUtil.add(sku.getPrice(), addedValueTax);
            sku.setPrice(price);
            // 原价税费
            addedValueTax = MathUtil.div(MathUtil.mul(sku.getNormalPrice(), product.getClubTaxPoint()), BigDecimal.valueOf(100), 2);
            price = MathUtil.add(sku.getNormalPrice(), addedValueTax);
            sku.setNormalPrice(price);
        }
        // 查询用户的注册时间
        Date registerTime = heheMapper.getUserRegisterTime(userId);
        String[] productIdArr = {product.getProductId().toString()};
        // 用户在该商品上可领取的优惠券列表
        List<HeheCouponVo> couponList = heheMapper.getCouponList(userId, productIdArr, registerTime, null);
        List<HeheCouponVo> receiveCouponList = new ArrayList<>();
        if (null != userId) {
            // 用户在该商品上已领取未使用的优惠券列表
            receiveCouponList = heheMapper.getReceiveCouponList(userId, productIdArr, null, 1);
            couponList.addAll(receiveCouponList);
        }
        // 单价满足优惠条件的优惠券列表
        List<HeheCouponVo> ableCouponList = new ArrayList<>();
        // 单价不满足优惠条件的优惠券列表
        List<HeheCouponVo> unableCouponList = new ArrayList<>();
        if (couponList.size() > 0) {
            // 有可用优惠券
            couponList.forEach(coupon -> {
                if (1 == coupon.getNoThresholdFlag() || MathUtil.compare(sku.getPrice(), coupon.getTouchPrice()) >= 0) {
                    ableCouponList.add(coupon);
                } else {
                    unableCouponList.add(coupon);
                }
            });
            if (ableCouponList.size() > 0) {
                // 根据优惠金额排序，优惠金额大的排前面
                ableCouponList.sort((o1, o2) -> o2.getCouponAmount().compareTo(o1.getCouponAmount()));
                HeheCouponVo biggestCoupon = ableCouponList.get(0);
                // 现价-最大优惠金额=券后价
                sku.setCouponPrice(MathUtil.sub(sku.getPrice(), biggestCoupon.getCouponAmount()));
                // 原价-最大优惠金额=原价券后价
                sku.setNormalCouponPrice(MathUtil.sub(sku.getNormalPrice(), biggestCoupon.getCouponAmount()));
                //这张优惠券未领取才返回优惠券id显示领券购买
                if (null != biggestCoupon.getUseStatus() && 0 == biggestCoupon.getUseStatus()) {
                    sku.setCouponId(biggestCoupon.getCouponId());
                }
                // 券后价标签
                sku.setCouponStatus(1);
            } else {
                // 根据优惠条件排序，条件小的排前面
                unableCouponList.sort(Comparator.comparing(HeheCouponVo::getTouchPrice));
                // 优惠券信息
                sku.setCouponStatus(2);
                HeheCouponVo smallestCoupon = unableCouponList.get(0);
                sku.setCouponInfo("券|满" + smallestCoupon.getTouchPrice() + "元减" + smallestCoupon.getCouponAmount());
            }
        }
    }

    /**
     * 设置楼层相关图片的商品信息
     */
    private void setFloorImageProduct(Integer userId, List<FloorImageVo> floorImageList) {
        Iterator<FloorImageVo> iterator = floorImageList.iterator();
        while (iterator.hasNext()) {
            FloorImageVo image = iterator.next();
            if (image.getProductId() != null) {
                // 获取商品及价格
                HeheProductVo product = heheMapper.getProduct(image.getProductId());
                if (product != null) {
                    setProductInfo(product, userId);
                    // 设置商品主图
                    image.setImage(ImageUtils.getImageURL("product", product.getMainImage(), 0, domain));
                    image.setHeheProduct(product);
                } else {
                    iterator.remove();
                }
            }
        }
    }

    /**
     * 设置跳转参数
     *
     * @param floorContent
     */
    private void setFloorLinkType(FloorContentVo floorContent) {
        if (floorContent != null) {
            if (null != floorContent.getJumpType1() && 1 == floorContent.getJumpType1() && StringUtils.isNotBlank(floorContent.getAdsLink1())) {
                Integer linkType1 = AppletsLinkUtil.getLinkType(floorContent.getAdsLink1());
                floorContent.setLinkType1(linkType1);
                floorContent.setLinkParam1(AppletsLinkUtil.getLinkParam(linkType1, floorContent.getAdsLink1()));
            }
            if (null != floorContent.getJumpType2() && 1 == floorContent.getJumpType2() && StringUtils.isNotBlank(floorContent.getAdsLink2())) {
                Integer linkType2 = AppletsLinkUtil.getLinkType(floorContent.getAdsLink2());
                floorContent.setLinkType2(linkType2);
                floorContent.setLinkParam2(AppletsLinkUtil.getLinkParam(linkType2, floorContent.getAdsLink2()));
            }
            if (null != floorContent.getJumpType3() && 1 == floorContent.getJumpType3() && StringUtils.isNotBlank(floorContent.getAdsLink3())) {
                Integer linkType3 = AppletsLinkUtil.getLinkType(floorContent.getAdsLink3());
                floorContent.setLinkType3(linkType3);
                floorContent.setLinkParam3(AppletsLinkUtil.getLinkParam(linkType3, floorContent.getAdsLink3()));
            }
            if (null != floorContent.getJumpType4() && 1 == floorContent.getJumpType4() && StringUtils.isNotBlank(floorContent.getAdsLink4())) {
                Integer linkType4 = AppletsLinkUtil.getLinkType(floorContent.getAdsLink4());
                floorContent.setLinkType4(linkType4);
                floorContent.setLinkParam4(AppletsLinkUtil.getLinkParam(linkType4, floorContent.getAdsLink4()));
            }
            if (null != floorContent.getJumpType5() && 1 == floorContent.getJumpType5() && StringUtils.isNotBlank(floorContent.getAdsLink5())) {
                Integer linkType3 = AppletsLinkUtil.getLinkType(floorContent.getAdsLink3());
                floorContent.setLinkType3(linkType3);
                floorContent.setLinkParam3(AppletsLinkUtil.getLinkParam(linkType3, floorContent.getAdsLink3()));
            }
        }
    }

}
