package com.caimei365.commodity.service.impl;

import com.caimei365.commodity.components.PriceUtilService;
import com.caimei365.commodity.mapper.MallOrganizeMapper;
import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.po.ProcurePo;
import com.caimei365.commodity.model.vo.*;
import com.caimei365.commodity.service.MallOrganizeService;
import com.caimei365.commodity.utils.MathUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/4/28
 */
@Service
@Slf4j
public class MallOrganizeServiceImpl implements MallOrganizeService {

    @Autowired private MallOrganizeMapper mallOrganizeMapper;
    @Autowired private ProcureService procureService;
    @Resource private PriceUtilService priceUtilService;
    /**
     * 联合丽格小程序首页
     *
     * @param organizeId
     * @return
     */
    @Override
    public ResponseJson<Map<String, Object>> getMallHome(Integer organizeId) {
        Map<String, Object> map = new HashMap<>();
        // 头部菜单
        List<MainmenuVo> mainmenu = mallOrganizeMapper.getMainmenu(organizeId);
        map.put("mainmenu", mainmenu);
        // banner图
        List<MallImageLinkVo> bannerImageList = mallOrganizeMapper.getMallBannerImages(organizeId);
        map.put("bannerList", bannerImageList);
        // 专题活动
        MallThemeVo mallThemeVos = mallOrganizeMapper.getmallTheme(organizeId);
        map.put("mallTheme", mallThemeVos);
        // 商品楼层
        List<MallFloorVo> floorList = mallOrganizeMapper.getFloorInfo(organizeId);
        // 楼层商品
        List<Integer> floorIds = floorList.stream().map(m -> m.getId()).collect(Collectors.toList());
        List<MallOrganizeProductVo> mallProducts = mallOrganizeMapper.getFloorProducts(floorIds);

        for (MallFloorVo floor : floorList) {
            if (null != mallProducts) {
                List<MallOrganizeProductVo> productVos = mallProducts.stream().filter(m -> m.getFloorId() == floor.getId()).collect(Collectors.toList());
                productVos.forEach( product -> {
                    // 计算税费
                    boolean taxFlag = (Integer.valueOf(0).equals(product.getIncludedTax()) && ("1".equals(product.getInvoiceType()) || "2".equals(product.getInvoiceType())));
                    if (taxFlag) {
                        product.setPrice(MathUtil.add(product.getPrice(), MathUtil.div(MathUtil.mul(product.getPrice(), product.getTaxRate()), 100, 2)).doubleValue());
                    }
                    // 价格等级
                    product.setPriceGrade(priceUtilService.getPriceGrade(product.getPrice()));
                });
                // 只显示6条
                if (productVos.size() > 6) {
                    floor.setProducts(productVos.subList(0, 6));
                } else {
                    floor.setProducts(productVos);
                }
            }
        }
        map.put("floorList", floorList);
        return ResponseJson.success(map);
    }

    /**
     * 主菜单区详情
     *
     * @param organizeId
     * @param activeId
     * @return
     */
    @Override
    public ResponseJson<Map<String,Object>> getMenu(Integer organizeId, Integer activeId) {
        Map<String, Object> map = new HashMap<>();
        // 菜单跳转活动
        if (null != activeId) {
            MallActiveVo active = mallOrganizeMapper.getActiveById(organizeId, activeId);
            if (null != active) {
                if ("1".equals(active.getActiveType())) {
                    // 商品列表
                    List<MallOrganizeProductVo> activeProduct = mallOrganizeMapper.getActiveProduct(activeId);
                    activeProduct.forEach(p -> {
                        // 设置价格等级
                        p.setPriceGrade(priceUtilService.getPriceGrade(p.getPrice()));
                    });
                    active.setProducts(activeProduct);
                } else {
                    // 活动宣传图
                    List<MallActiveImageVo> imageList = mallOrganizeMapper.getActiveImageById(activeId);
                    active.setActiveImageVos(imageList);
                }
            } else {
                return ResponseJson.error(-1,"该活动不存在，请联系维护人员",null);
            }
            map.put("active", active);
        } else {
            return ResponseJson.error(-1,"该活动不存在，请联系维护人员",null);
        }
        return ResponseJson.success(map);
    }

    /**
     * 活动商品列表
     *
     * @return
     */
    @Override
    public ResponseJson<List<MallOrganizeProductVo>> activeProduct(Integer imageId) {
        // 活动类型
        MallActiveVo activeInfo = mallOrganizeMapper.getActiveInfo(imageId);
        // 活动商品信息
        List<MallOrganizeProductVo> menuList = mallOrganizeMapper.getImageProduct(imageId);
        menuList.forEach(p -> {
            // 价格等级
            p.setPriceGrade(priceUtilService.getPriceGrade(p.getPrice()));
            if (StringUtils.isBlank(p.getTopic())) {
                if (StringUtils.isNotBlank(activeInfo.getTopic())) {
                    p.setTopic(activeInfo.getTopic());
                } else {
                    p.setTopic("未知");
                }
            }
        });

        return ResponseJson.success(menuList);
    }

    /**
     * 商品楼层详情
     *
     * @param floorId
     * @return
     */
    @Override
    public ResponseJson<List<MallOrganizeProductVo>> getOrganizeProducts(Integer floorId) {
        List<MallOrganizeProductVo> organizeProducts = mallOrganizeMapper.getOrganizeProducts(floorId);
        organizeProducts.forEach(p -> {
            // 计算税费
            boolean taxFlag = (Integer.valueOf(0).equals(p.getIncludedTax()) && ("1".equals(p.getInvoiceType()) || "2".equals(p.getInvoiceType())));
            if (taxFlag) {
                p.setPrice(MathUtil.add(p.getPrice(), MathUtil.div(MathUtil.mul(p.getPrice(), p.getTaxRate()), 100, 2)).doubleValue());
            }
            // 价格等级
            p.setPriceGrade(priceUtilService.getPriceGrade(p.getPrice()));
        });
        return ResponseJson.success(organizeProducts);
    }

    /**
     * 专题活动 只有一个已启用状态的活动
     *
     * @return
     */
    @Override
    public ResponseJson<Map<String,Object>> getThemeInfo() {
        Map<String ,Object> map = new HashMap<>();
        // 专题活动
        MallThemeVo themeInfo = mallOrganizeMapper.getThemeInfo();
        if (null != themeInfo) {
            if ("1".equals(themeInfo.getJumpType())) {
                // 1商品详情
                MallOrganizeProductVo themeProduct = mallOrganizeMapper.getMenuProductList(themeInfo.getOrganizeId(), themeInfo.getJumpProductId());
                map.put("themeProduct", themeProduct);
            } else {
                // 菜单跳转活动
                if (null != themeInfo.getJumpActiveId()) {
                    MallActiveVo active = mallOrganizeMapper.getActiveById(themeInfo.getOrganizeId(), themeInfo.getJumpActiveId());
                    // 活动宣传图
                    List<MallActiveImageVo> imageList = mallOrganizeMapper.getActiveImageById(themeInfo.getJumpActiveId());
                    // 活动商品信息
                    List<MallOrganizeProductVo> menuList = mallOrganizeMapper.getMenuActiveList(themeInfo.getJumpActiveId());
                    menuList.forEach(p -> {
                        // 价格等级
                        p.setPriceGrade(priceUtilService.getPriceGrade(p.getPrice()));
                    });
                    active.setProducts(menuList);
                    active.setActiveImageVos(imageList);
                    map.put("active", active);
                } else {
                    return ResponseJson.error(-1,"该活动不存在，请联系维护人员",null);
                }
            }
        }
        return ResponseJson.success(map);
    }
}
