package com.caimei365.commodity.service.impl;

import com.caimei365.commodity.mapper.ProcureRepository;
import com.caimei365.commodity.model.po.AdditionalPo;
import com.caimei365.commodity.model.po.ProcurePo;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.data.mongodb.core.query.Update;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/4/25
 */
@Service
public class ProcureService {

    @Resource
    private ProcureRepository procureRepository;
    @Resource
    private MongoTemplate mongoTemplate;


    /**
     * 保存
     *
     * @param procure
     */
    public void save(ProcurePo procure) {
        //如果需要自定义主键，可以在这里指定主键；如果不指定主键，MongoDB会自动生成主键
        //设置一些默认初始值。。。
        //调用dao
        procureRepository.save(procure);
    }

    /**
     * 修改delFlag
     *
     * @param procure
     */
    public void update(ProcurePo procure) {
        Query query = Query.query(Criteria.where("_id").is(procure.getId()));
        Update update = Update.update("delFlag", procure.getDelFlag());
        //  更新一条数据
        mongoTemplate.updateFirst(query, update, ProcurePo.class);
    }

    /**
     * 修改
     *
     * @param procure
     */
    public void updateFirst(ProcurePo procure) {
        Query query = Query.query(Criteria.where("_id").is(procure.getId()));
        Update update = Update
                .update("price", procure.getPrice())
                .set("number", procure.getNumber());
        //  更新一条数据
        mongoTemplate.updateFirst(query, update, ProcurePo.class);
    }

    public void findList() {
        //调用dao
        Query query = new Query();
        query.addCriteria(Criteria.where("delFlag").is("0"));
        query.with(Sort.by(Sort.Direction.DESC, "saveTime"));
        List<ProcurePo> procurePos = mongoTemplate.find(query, ProcurePo.class);
        System.out.println(procurePos);
    }

    /**
     * 根据id删除
     *
     * @param id
     */
    public void deleteById(String id) {
        //调用dao
        procureRepository.deleteById(id);
    }

    /**
     * 查询所有集采
     *
     * @return
     */
    public List<ProcurePo> findList(int pageNo, int pageSize, Integer userId, Integer status) {
//        Pageable pageable = PageRequest.of(pageNo - 1, pageSize, Sort.by(Sort.Order.desc("saveTime")));
        Query query = new Query();
        query.addCriteria(Criteria.where("createUserId").ne(null));
        if (status == 1) {
            // 我参与的
            query.addCriteria(Criteria.where("userId").ne(userId.toString()));
            query.addCriteria(Criteria.where("delFlag").is("0"));
        } else if (status == 2) {
            // 我发起的
            query.addCriteria(Criteria.where("userId").is(userId.toString()));
            query.addCriteria(Criteria.where("isInvolved").is(2));
        } else {
            // 所有
            query.addCriteria(Criteria.where("delFlag").is("0"));
        }
        query.with(Sort.by(Sort.Direction.DESC, "saveTime"));
        List<ProcurePo> procurePos = mongoTemplate.find(query, ProcurePo.class);
        /*long count1 = mongoTemplate.count(query, ProcurePo.class);
        PageImpl<ProcurePo> procurePos1 = new PageImpl<>(procurePos, pageable, count1);*/
        return procurePos;
    }

    /**
     * 根据id查询
     *
     * @param id
     * @return
     */
    public ProcurePo findById(String id) {
        //调用dao
        return procureRepository.findById(id).get();
    }

    /**
     * 我参与的集采
     *
     * @param userId
     * @return
     */
    public List<ProcurePo> findInvolvedList(String userId) {
        Query query = new Query();
        query.addCriteria(Criteria.where("userId").is(userId));
        query.addCriteria(Criteria.where("createUserId").is(null));
        query.with(Sort.by(Sort.Direction.DESC, "saveTime"));
        query.with(Sort.by(Sort.Direction.DESC, "isAchieve"));
        /*List<ProcurePo> procureList = mongoTemplate.find(query, ProcurePo.class);
        procureList.forEach(p -> {

        });*/
        return mongoTemplate.find(query, ProcurePo.class);
    }

    /**
     * 我发起的集采
     *
     * @param userId
     * @return
     */
    public List<ProcurePo> findUserList(String userId) {
        Query query = new Query();
        query.addCriteria(Criteria.where("createUserId").is(userId));
        query.with(Sort.by(Sort.Direction.DESC, "saveTime"));
        query.with(Sort.by(Sort.Direction.DESC, "isAchieve"));
        return mongoTemplate.find(query, ProcurePo.class);
    }

    public ProcurePo editData(Integer id, Integer userId) {
        Query query = new Query();
        query.addCriteria(Criteria.where("id").is(id));
        query.addCriteria(Criteria.where("userId").is(userId));
        return mongoTemplate.find(query, ProcurePo.class).get(0);
    }
}
