package com.caimei365.commodity.service.impl;

import com.caimei365.commodity.mapper.ProcurementMapper;
import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.dto.ProcurementDto;
import com.caimei365.commodity.model.po.AdditionalPo;
import com.caimei365.commodity.model.po.ProcurePo;
import com.caimei365.commodity.model.vo.PaginationVo;
import com.caimei365.commodity.model.vo.UserVo;
import com.caimei365.commodity.service.ProcurementService;
import com.caimei365.commodity.utils.ImageUtils;
import com.caimei365.commodity.utils.ListPagingUtil;
import com.caimei365.commodity.utils.MongodbUtils;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/4/26
 */
@Slf4j
@Service
public class ProcurementServiceImpl implements ProcurementService {
    @Value("${caimei.wwwDomain}")
    private String domain;

    @Autowired ProcurementMapper procurementMapper;
    // 集采 | 接龙参与信息
    @Resource  ProcureService procureService;
    // 发起与参与关联
    @Resource AdditionalService additionalService;


    /**
     * 所有集采
     *
     * @param pageNo
     * @param pageSize
     * @param status   0全部，1参与，2我创建
     * @return
     */
    @Override
    public ResponseJson<PageInfo<ProcurementDto>> findList(int pageNo, int pageSize, Integer userId, Integer status) {
        SimpleDateFormat returnFormat = new SimpleDateFormat("yyyy-MM-dd");
//        PageHelper.startPage(pageNo, pageSize);
        List<ProcurementDto> procurementList = new ArrayList<>();
        // 我参与的
        List<ProcurePo> involvedList = procureService.findInvolvedList(userId.toString());
        // 参与者记录
        //  List<AdditionalPo> additionalPos = additionalService.findList();
        // 所有集采信息
        List<ProcurePo> list = procureService.findList(pageNo, pageSize, userId, status);

        if (null != list && list.size() > 0) {
            list.forEach(p -> {
                ProcurementDto procurementDto = new ProcurementDto();
                // 参与集采集合
                List<AdditionalPo> additionalPoList = additionalService.findProcureById(p.getId());
                procurementDto.setId(p.getId());
                procurementDto.setUserId(p.getUserId());

                procurementDto.setUserName(p.getClubName());
                String imageURL = ImageUtils.getImageURL("product", p.getProductImage(), 0, domain);
                if (StringUtils.isNotBlank(imageURL)) {
                    procurementDto.setProductImage(imageURL);
                }
                procurementDto.setProductName(p.getProductName());
                procurementDto.setPrice(p.getPrice());
                procurementDto.setSaveTime(returnFormat.format(p.getSaveTime()));
                if (StringUtils.isNotBlank(p.getCreateUserId())) {
                    procurementDto.setCreateUserId(p.getCreateUserId());
                }
                procurementDto.setNumber(p.getNumber());
                procurementDto.setIsAchieve(p.getIsAchieve());
                // 是否参与
                if (p.getCreateUserId().equals(userId.toString())) {
                    procurementDto.setIsInvolved(2);
                } else {
                    List<String> stringList = additionalPoList.stream().map(a -> a.getAdditionalId()).collect(Collectors.toList());
                    List<ProcurePo> collect = involvedList.stream().filter(item -> stringList.contains(item.getId())).collect(Collectors.toList());
                    if (null != collect && collect.size() > 0) {
                        procurementDto.setIsInvolved(1);
                    } else {
                        procurementDto.setIsInvolved(0);
                    }
                }
                procurementDto.setDelFlag(p.getDelFlag());
                // 参与机构数量
                procurementDto.setPartNumber(additionalPoList.size());
                if (!p.getUserId().equals(userId)) {
                    additionalService.findProcureById(p.getId()).forEach(s -> {
                        if (s.getProcureId().equals(p.getId()) && involvedList.stream().map(ProcurePo::getId).collect(Collectors.toList()).contains(s.getAdditionalId())) {
                            procurementDto.setSId(s.getAdditionalId());
                        }
                        procurementDto.setProcurePo(procureService.findById(s.getAdditionalId()));
                    });
                }
                if (status == 0||(status != 0&&procurementDto.getIsInvolved() != 0 )) {
                    procurementList.add(procurementDto);
                }
            });
        }
        PageInfo<ProcurementDto> page = new PageInfo();
        page.setPageNum(pageNo);
        page.setPageSize(pageSize);
        page.setTotal(procurementList.size());
        page.setList(ListPagingUtil.listPaging(procurementList, pageNo, pageSize));
        return ResponseJson.success(page);
    }



    /**
     * 查看详情
     *
     * @param id
     * @return
     */
    @Override
    public ResponseJson<Map<String, Object>> detailProcurement(String id, Integer userId) {
        SimpleDateFormat returnFormat = new SimpleDateFormat("yyyy-MM-dd");

        Map<String, Object> map = new HashMap<>();
        // 我参与的
        List<ProcurePo> involvedList = procureService.findInvolvedList(userId.toString());
        // 参与集采集合
        List<AdditionalPo> additionalPoLi = additionalService.findProcureById(id);
        // 参与者集合
        List<ProcurementDto> procurementList = new ArrayList<>();
        ProcurementDto procurementDto = new ProcurementDto();
        // 发起者
        ProcurePo procurePo = procureService.findById(id.toString());

        // 发起者信息设置
        procurementDto.setId(procurePo.getId());
        procurementDto.setUserId(procurePo.getUserId());
        procurementDto.setUserName(procurePo.getClubName());
        procurementDto.setProductImage(procurePo.getProductImage());
        procurementDto.setProductName(procurePo.getProductName());
        procurementDto.setPrice(procurePo.getPrice());
        procurementDto.setSaveTime(returnFormat.format(procurePo.getSaveTime()));
        if (StringUtils.isNotBlank(procurePo.getCreateUserId())) {
            procurementDto.setCreateUserId(procurePo.getCreateUserId());
        }
        procurementDto.setNumber(procurePo.getNumber());
        procurementDto.setIsAchieve(procurePo.getIsAchieve());
        // 是否参与
        List<AdditionalPo> additionalPos = additionalService.findProcureById(procurePo.getId());
        String Iscreate = procurePo.getCreateUserId() == null ? "0" : procurePo.getCreateUserId();
        if (Iscreate.equals(userId.toString())) {
            procurementDto.setIsInvolved(2);
        } else {
            List<String> stringList = additionalPos.stream().map(a -> a.getAdditionalId()).collect(Collectors.toList());
            List<ProcurePo> collect = involvedList.stream().filter(item -> stringList.contains(item.getId())).collect(Collectors.toList());
            if (null != collect && collect.size() > 0) {
                procurementDto.setIsInvolved(1);
            } else {
                procurementDto.setIsInvolved(0);
            }
        }
        // sid
        log.info("involvedList====="+involvedList);
        for(AdditionalPo add: additionalPoLi) {
            if (add.getProcureId().equals(procurePo.getId()) && involvedList.stream().map(ProcurePo::getId).collect(Collectors.toList()).contains(add.getAdditionalId())) {
                procurementDto.setSId(add.getAdditionalId());
            }
        }
        procurementDto.setDelFlag(procurePo.getDelFlag());
        map.put("procurement", procurementDto);

        List<AdditionalPo> additionalPoList =( List<AdditionalPo> ) MongodbUtils.find(AdditionalPo.class, new String[]{"procureId"}, new String[]{procurePo.getId()});
        for (AdditionalPo s : additionalPoList) {
            ProcurementDto procurement = new ProcurementDto();
            // 参与者
            ProcurePo procure = procureService.findById(s.getAdditionalId());

            // 参与者信息设置
            procurement.setId(procure.getId());
            procurement.setUserId(procure.getUserId());

            procurement.setUserName(procure.getClubName());
            procurement.setProductImage(procure.getProductImage());
            procurement.setProductName(procure.getProductName());
            procurement.setPrice(procure.getPrice());
            procurement.setSaveTime(returnFormat.format(procure.getSaveTime()));
            if (StringUtils.isNotBlank(procure.getCreateUserId())) {
                procurement.setCreateUserId(procurePo.getCreateUserId());
            }
            procurement.setNumber(procure.getNumber());
            procurement.setIsAchieve(procure.getIsAchieve());
            procurement.setDelFlag(procure.getDelFlag());
            if (procurement.getCreateUserId() == null) {
                procurement.setIsInvolved(1);
            } else {
                procurement.setIsInvolved(2);
            }
            procurementList.add(procurement);
        }

        map.put("procurementList", procurementList);
        return ResponseJson.success(map);
    }

    /**
     * 我参与的 | 我创建的
     *
     * @param userId
     * @param procurementType 0 我参与的 1 我发起的
     * @return
     */
    @Override
    public ResponseJson<List<ProcurementDto>> myProcurement(Integer userId, Integer procurementType) {
        SimpleDateFormat returnFormat = new SimpleDateFormat("yyyy-MM-dd");

        List<ProcurementDto> procurementList = new ArrayList<>();
        // 参与者记录
        List<AdditionalPo> additionalPos = additionalService.findList();

        List<ProcurePo> list = new ArrayList<>();
        if (0 == procurementType) {
            // 我参与的
            list = procureService.findInvolvedList(userId.toString());
        } else {
            // 我发起的
            list = procureService.findUserList(userId.toString());
        }
        // 设置返回信息
        if (null != list && list.size() > 0) {
            list.forEach(p -> {
                // 返回填充
                ProcurementDto procurementDto = new ProcurementDto();

                if (0 == procurementType) {
                    // 我参与的
                    procurementDto.setIsInvolved(1);
                    // 主集采信息
                    AdditionalPo additionalPo = additionalService.findAdditionalById(p.getId());
                    // 主集采信息
                    ProcurePo pro = procureService.findById(additionalPo.getProcureId());
                    if (!procurementList.stream().map(ProcurementDto::getId).collect(Collectors.toList()).contains(pro.getId())) {
                        procurementDto.setId(pro.getId());
                        procurementDto.setSId(p.getId());
                        procurementDto.setUserId(pro.getUserId());
                        String imageURL = ImageUtils.getImageURL("product", pro.getProductImage(), 0, domain);
                        if (StringUtils.isNotBlank(imageURL)) {
                            procurementDto.setProductImage(imageURL);
                        }
                        procurementDto.setProductName(pro.getProductName());
                        procurementDto.setPrice(pro.getPrice());
                        procurementDto.setSaveTime(returnFormat.format(pro.getSaveTime()));
                        if (StringUtils.isNotBlank(pro.getCreateUserId())) {
                            procurementDto.setCreateUserId(pro.getCreateUserId());
                        }
                        procurementDto.setNumber(pro.getNumber());
                        procurementDto.setIsAchieve(pro.getIsAchieve());
                        procurementDto.setDelFlag(pro.getDelFlag());
                        Integer count = Collections.frequency(additionalPos, pro.getId());

                        procurementDto.setPartNumber(count);
                        procurementList.add(procurementDto);
                    }
                } else {
                    // 我发起的
                    procurementDto.setIsInvolved(2);
                    procurementDto.setSId(p.getId());
                    procurementDto.setUserId(p.getUserId());
                    String imageURL = ImageUtils.getImageURL("product", p.getProductImage(), 0, domain);
                    if (StringUtils.isNotBlank(imageURL)) {
                        procurementDto.setProductImage(imageURL);
                    }
                    procurementDto.setProductName(p.getProductName());
                    procurementDto.setPrice(p.getPrice());
                    procurementDto.setSaveTime(returnFormat.format(p.getSaveTime()));
                    if (StringUtils.isNotBlank(p.getCreateUserId())) {
                        procurementDto.setCreateUserId(p.getCreateUserId());
                    }
                    procurementDto.setNumber(p.getNumber());
                    procurementDto.setIsAchieve(p.getIsAchieve());
                    procurementDto.setDelFlag(p.getDelFlag());
                    Integer count = Collections.frequency(additionalPos, p.getId());

                    procurementDto.setPartNumber(count);
                    procurementList.add(procurementDto);
                }

            });
        }
        // 用户信息获取
        List<String> userIds = procurementList.stream().map(ProcurementDto::getUserId).collect(Collectors.toList());
        List<UserVo> userInfo = procurementMapper.selUserInfo(userIds);
        // 用户信息赋予
        if (null != userInfo) {
            procurementList.forEach(p -> {
                Integer i = Integer.parseInt(p.getUserId());
                List<UserVo> collect = userInfo.stream().filter(u -> u.getUserId().equals(i)).collect(Collectors.toList());
                if (null != collect && collect.size() > 0) {
                    p.setUserName(collect.get(0).getUserName());
                }
            });
        }
        return ResponseJson.success(procurementList);
    }

    /**
     * 修改集采信息回显
     *
     * @param id
     * @param userId
     * @param procurementType 0 我参与的 1 我发起的
     * @return
     */
    @Override
    public ResponseJson<ProcurementDto> editData(String id, Integer userId, Integer procurementType) {
        SimpleDateFormat saveFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        ProcurementDto procurementDto = new ProcurementDto();
        List<ProcurePo> involvedList = new ArrayList<>();
        if (0 == procurementType) {
            // 我参与的集采修改回显
            involvedList = procureService.findInvolvedList(userId.toString());
            procurementDto.setIsInvolved(1);
        } else {
            // 我发起的集采修改回显
            involvedList = procureService.findUserList(userId.toString());
            procurementDto.setIsInvolved(2);
        }
        // 检索匹配
        ProcurePo procurePo = null;
        for (ProcurePo s : involvedList) {
            if (id.equals(s.getId())) {
                procurePo = s;
            }
        }
        // 返回赋值
        procurementDto.setId(procurePo.getId());
        procurementDto.setUserId(procurePo.getUserId());

        procurementDto.setUserName(procurePo.getClubName());
        String imageURL = ImageUtils.getImageURL("product", procurePo.getProductImage(), 0, domain);
        if (StringUtils.isNotBlank(imageURL)) {
            procurementDto.setProductImage(imageURL);
        }
        procurementDto.setProductName(procurePo.getProductName());
        procurementDto.setPrice(procurePo.getPrice());
        procurementDto.setSaveTime(saveFormat.format(new Date()));
        if (StringUtils.isNotBlank(procurePo.getCreateUserId())) {
            procurementDto.setCreateUserId(procurePo.getCreateUserId());
        }
        procurementDto.setNumber(procurePo.getNumber());
        procurementDto.setIsAchieve(procurePo.getIsAchieve());
        procurementDto.setDelFlag(procurePo.getDelFlag());
        return ResponseJson.success(procurementDto);
    }

    /**
     * 发布集采 | 修改集采
     *
     * @param procurementDto
     * @return
     */
    @Override
    public ResponseJson saveProcurement(ProcurementDto procurementDto) throws Exception {
        SimpleDateFormat saveFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        ProcurePo procurePo = new ProcurePo();
        // 初始化数据
        procurePo.setUserId(procurementDto.getUserId());
        procurePo.setProductImage(procurementDto.getProductImage());
        procurePo.setProductName(procurementDto.getProductName());
        procurePo.setPrice(procurementDto.getPrice());
        String time = saveFormat.format(new Date());
        procurePo.setSaveTime(saveFormat.parse(time).getTime());
        procurePo.setNumber(procurementDto.getNumber());
        if (StringUtils.isNotBlank(procurementDto.getId())) {
            // 修改集采信息
            procurePo.setId(procurementDto.getId());
            MongodbUtils.updateFirst("_id", procurePo.getId(),
                    new String[]{"productImage", "productName", "price", "number"},
                    new String[]{procurePo.getProductImage(),
                            procurePo.getProductName(),
                            procurePo.getPrice(),
                            procurePo.getNumber()},
                    ProcurePo.class);
        } else {
            // 发布集采需求
            procurePo.setCreateUserId(procurementDto.getUserId());
            procurePo.setClubName(procurementDto.getUserName());
            procurePo.setIsAchieve("0");
            procurePo.setIsInvolved(2);
            procurePo.setDelFlag("0");
            procureService.save(procurePo);
        }
        return ResponseJson.success();
    }

    /**
     * 参与集采
     *
     * @param procurementDto
     * @return
     */
    @Override
    public ResponseJson participateProcurement(ProcurementDto procurementDto,Integer status) throws Exception {
        SimpleDateFormat saveFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        ProcurePo procurePo = new ProcurePo();
        String id=procurementDto.getId();
        if (status ==1) {
            id=((AdditionalPo)MongodbUtils.find(AdditionalPo.class, new java.lang.String[]{"additionalId"}, new java.lang.String[]{procurementDto.getId()}).get(0)).getProcureId();
            MongodbUtils.removeById("additionalId", procurementDto.getId(), AdditionalPo.class);
            MongodbUtils.removeById("_id", procurementDto.getId(), ProcurePo.class);
        }
        // 参与集采需求
        procurePo.setUserId(procurementDto.getUserId());
        procurePo.setProductImage(procurementDto.getProductImage());
        procurePo.setProductName(procurementDto.getProductName());
        procurePo.setPrice(procurementDto.getPrice());
        String time = saveFormat.format(new Date());
        procurePo.setSaveTime(Long.valueOf(saveFormat.parse(time).getTime()));
        procurePo.setNumber(procurementDto.getNumber());
        procurePo.setClubName(procurementDto.getUserName());
        procurePo.setIsAchieve("0");
        procurePo.setIsInvolved(1);
        procurePo.setDelFlag("0");

        procureService.save(procurePo);
        // 设置集采 发布与参与对应关系
        AdditionalPo additionalPo = new AdditionalPo();
        additionalPo.setProcureId(id);
        additionalPo.setAdditionalId(procurePo.getId());
        additionalPo.setDelFlag("0");
        additionalService.save(additionalPo);
        return ResponseJson.success();
    }

    /**
     * 删除集采 | 退出集采
     *
     * @param id
     * @param userId
     * @param procurementType 0 删除集采 1 退出集采
     * @return
     */
    @Override
    public ResponseJson updateProcurement(String id, Integer userId, Integer procurementType) {
        // 更新集采信息
        if (1 == procurementType) {
            // 退出集采
            procureService.deleteById(id);
            // 删除关系
            additionalService.deleteByAdditionalId(id);
        } else {
            // 删除集采
            ProcurePo procurePo = new ProcurePo();
            procurePo.setId(id.toString());
            procurePo.setDelFlag("1");
            procureService.update(procurePo);
            // 删除集采关系
            AdditionalPo additionalPo = new AdditionalPo();
            additionalPo.setId(id.toString());
            additionalPo.setDelFlag("1");
            additionalService.update(additionalPo);
        }
        return ResponseJson.success();
    }


}
