package com.caimei365.commodity.service.impl;

import com.caimei365.commodity.mapper.PromotionsMapper;
import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.vo.ProductItemVo;
import com.caimei365.commodity.model.vo.ImageLinkVo;
import com.caimei365.commodity.model.vo.PromotionsVo;
import com.caimei365.commodity.service.PromotionsService;
import com.caimei365.commodity.utils.AppletsLinkUtil;
import com.caimei365.commodity.utils.ImageUtils;
import com.caimei365.commodity.components.PriceUtilService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/9
 */
@Slf4j
@Service
public class PromotionsServiceImpl implements PromotionsService {
    @Value("${caimei.wwwDomain}")
    private String domain;
    @Resource
    private PromotionsMapper promotionsMapper;
    @Resource
    private PriceUtilService priceUtilService;
    /**
     * 专题活动列表数据
     *
     * @param source   来源
     * @return List<PromotionsVo>
     */
    @Override
    public ResponseJson<PageInfo<ImageLinkVo>> getPromotionsList(Integer source, int pageNum, int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<ImageLinkVo> promotionsList = promotionsMapper.getPromotionsList(source);
        if (!CollectionUtils.isEmpty(promotionsList)) {
            promotionsList.forEach(item -> {
                //链接类型获取
                if (StringUtils.isNotEmpty(item.getLink())) {
                    item.setLinkType(AppletsLinkUtil.getLinkType(item.getLink()));
                    item.setLinkParam(AppletsLinkUtil.getLinkParam(item.getLinkType(), item.getLink()));
                }
            });
        }
        PageInfo<ImageLinkVo> pageInfo = new PageInfo(promotionsList);
        return ResponseJson.success(pageInfo);
    }

    /**
     * 获取促销活动详情
     *
     * @param promotionsId 促销活动Id
     * @return PromotionsVo
     */
    @Override
    public ResponseJson<PromotionsVo> getPromotionDetails(Integer promotionsId) {
        PromotionsVo promotions = promotionsMapper.getPromotionsById(promotionsId);
        if (null != promotions) {
            List<ProductItemVo> productGifts = promotionsMapper.getPromotionGifts(promotionsId);
            productGifts.forEach(p -> {
                p.setImage(ImageUtils.getImageURL("product", p.getImage(), 0, domain));
            });
            promotions.setGiftList(productGifts);
        }
        return ResponseJson.success(promotions);
    }

    /**
     * 获取促销活动凑单商品
     *
     * @param promotionsId 促销活动id
     * @param identity
     * @param pageNum
     * @param pageSize
     */
    @Override
    public ResponseJson<PageInfo<ProductListVo>> getPromotionProduct(Integer promotionsId, Integer identity, int pageNum, int pageSize) {
        // identity: 0个人，1协销，2会员机构，3供应商，4普通机构，5医美机构
        // visibility：3:所有人可见，2:普通机构可见，1:会员机构可见，4:仅医美机构可见
        List<Integer> visibilityList = new ArrayList<>();
        if (identity == 1 || identity == 5) {
            // 协销 | 医美机构 | 综合供应商
            visibilityList.addAll(Arrays.asList(1,2,3,4));
        } else if (identity == 2) {
            // 会员机构
            visibilityList.addAll(Arrays.asList(1,2,3));
        } else if (identity == 4) {
            // 普通机构
            visibilityList.addAll(Arrays.asList(2,3));
        } else {
            // 游客|所有人
            visibilityList.add(3);
        }
        PageHelper.startPage(pageNum, pageSize);
        List<ProductListVo> list = promotionsMapper.getProductListByPromotions(promotionsId, visibilityList);
        // 设置价格等级 及 老图片路径
        list.forEach(product -> {
            product.setPriceGrade(priceUtilService.getPriceGrade(product.getPrice()));
            product.setPrice(0d);
            product.setImage(ImageUtils.getImageURL("product", product.getImage(), 0, domain));
        });
        PageInfo<ProductListVo> pageInfo = new PageInfo(list);
        return ResponseJson.success(pageInfo);
    }

    /**
     * 详情-获取赠品
     *
     * @param promotionsId 促销活动Id
     */
    @Override
    public ResponseJson<List<ProductItemVo>> getPromotionGifts(Integer promotionsId) {
        List<ProductItemVo> list = promotionsMapper.getPromotionGifts(promotionsId);
        return ResponseJson.success(list);
    }
}
