package com.caimei365.commodity.service.impl;

import com.aliyun.opensearch.sdk.dependencies.org.json.JSONArray;
import com.aliyun.opensearch.sdk.dependencies.org.json.JSONException;
import com.aliyun.opensearch.sdk.dependencies.org.json.JSONObject;
import com.aliyun.opensearch.sdk.generated.commons.OpenSearchClientException;
import com.aliyun.opensearch.sdk.generated.commons.OpenSearchException;
import com.aliyun.opensearch.sdk.generated.search.DeepPaging;
import com.aliyun.opensearch.sdk.generated.search.SearchParams;
import com.caimei365.commodity.components.PriceUtilService;
import com.caimei365.commodity.components.RedisService;
import com.caimei365.commodity.components.SearchOpenService;
import com.caimei365.commodity.mapper.PageMapper;
import com.caimei365.commodity.mapper.SearchFrequencyMapper;
import com.caimei365.commodity.mapper.SearchMapper;
import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.po.SearchHistoryPo;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.vo.HotSearchVo;
import com.caimei365.commodity.model.vo.PaginationVo;
import com.caimei365.commodity.model.vo.SearchFrequencyVo;
import com.caimei365.commodity.model.vo.SearchKeywordyVo;
import com.caimei365.commodity.service.SearchProductService;
import com.caimei365.commodity.utils.AppletsLinkUtil;
import com.caimei365.commodity.utils.Json2PojoUtil;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/7
 */
@Slf4j
@Service
public class SearchProductServiceImpl implements SearchProductService {

    private static final Integer SEARCH_MAX_NUM = 500;
    @Value("${caimei.wwwDomain}")
    private String domain;
    @Resource
    private SearchMapper searchMapper;
    @Resource
    private PageMapper pageMapper;
    @Resource
    private SearchOpenService searchOpenService;
    @Resource
    private PriceUtilService priceUtilService;

    @Resource
    private SearchFrequencyMapper searchFrequencyMapper;

    @Autowired
    private RedisService redisService;

    /**
     * 根据关键词搜索商品
     *
     * @param keyword       搜索关键字
     * @param brandIds      品牌id字符串，逗号隔开
     * @param newFlag       查询新品标记
     * @param promotionFlag 查询促销活动标记
     * @param pageNum       页码
     * @param pageSize      每页数量
     * @param sortField     排序字段
     * @param sortType      升降序0/1
     * @return JsonStr(list)
     */
    @Override
    public ResponseJson<String> queryProductByKeyword(String keyword, String brandIds, Integer identity, Integer newFlag, Integer promotionFlag,
                                                      int pageNum, int pageSize, String sortField, Integer sortType) {
        String queryStr = "product:'" + keyword + "'";
        if (StringUtils.isEmpty(keyword)) {
            queryStr = "p_all:'1'";
        }
        List<String> filterList = new ArrayList<>();
        if (newFlag == 1) {
            filterList.add("p_newvalidflag = 1");
        }
        if (promotionFlag == 1) {
            filterList.add("p_promotions_id > 0");
        }
        if (!StringUtils.isEmpty(brandIds) && !"null".equals(brandIds)) {
            StringBuffer brandBuilder = new StringBuffer();
            List<String> brandList = new ArrayList<>();
            String[] split = brandIds.split(",");
            for (String s : split) {
                if (!StringUtils.isEmpty(s) && !"null".equals(s)) {
                    brandList.add(s);
                }
            }
            for (int i = 0; i < brandList.size(); i++) {
                if (i == 0) {
                    brandBuilder.append("p_brand_id = ").append(brandList.get(i));
                } else {
                    brandBuilder.append(" OR ").append("p_brand_id = ").append(brandList.get(i));
                }
            }
            String brandFilter = brandBuilder.toString();
            if (brandFilter.contains("OR")) {
                brandFilter = "(" + brandFilter + ")";
            }
            if (!StringUtils.isEmpty(brandFilter)) {
                filterList.add(brandFilter);
            }
        }
        String filter = "";
        StringBuffer filterBuffer = new StringBuffer();
        if (filterList.size() > 0) {
            for (int i = 0; i < filterList.size(); i++) {
                if (i == 0) {
                    filterBuffer.append(filterList.get(i));
                } else {
                    filterBuffer.append(" AND ").append(filterList.get(i));
                }
            }
            filter = filterBuffer.toString();
        }
        // 阿里云搜索
        ResponseJson<String> result = queryProduct(queryStr, filter, identity, pageNum, pageSize, sortField, sortType);
        if (0 == result.getCode()) {
            return result;
        } else {
            // 阿里云搜索失败，再次从数据库搜索
            return queryProductFromDatabase(pageNum, pageSize, identity, keyword, null, null, null, null, null, sortField, sortType);
        }
    }


    @Override
    public ResponseJson<Set<HashMap<String, Object>>> queryBrand(String keyword, Integer id, Integer idType, Integer newFlag, Integer promotionFlag, Integer identity) {
        String queryStr = "";
        String filter = "";
        if (!StringUtils.isEmpty(keyword) && idType == null && id == null) {
            queryStr = "product:'" + keyword + "'";
        } else if (StringUtils.isEmpty(keyword) && idType != null && id != null) {
            if (idType == 1) {
                queryStr = "p_bigtype:'" + id + "'";
            } else if (idType == 2) {
                queryStr = "p_smalltype:'" + id + "'";
            } else if (idType == 3) {
                queryStr = "p_tinytype:'" + id + "'";
            }
        } else if ((!StringUtils.isEmpty(keyword)) && idType != null && id != null) {
            if (idType == 1) {
                queryStr = "product:'" + keyword + "' AND " + "p_bigtype:'" + id + "'";
            }
            if (idType == 2) {
                queryStr = "product:'" + keyword + "' AND " + "p_smalltype:'" + id + "'";
            }
            if (idType == 3) {
                queryStr = "product:'" + keyword + "' AND " + "p_tinytype:'" + id + "'";
            }
        } else {
            queryStr = "p_all:'1'";
        }
        if (newFlag == 1) {
            Calendar c = Calendar.getInstance();
            c.setTime(new Date());
            c.add(Calendar.YEAR, -1);
            String time = new SimpleDateFormat("yyyyMMdd").format(c.getTime());
            filter += "p_time > " + time;
        }
        if (promotionFlag == 1) {
            if (newFlag == 1) {
                filter += "AND p_promotions_id > 0";
            } else {
                filter += "p_promotions_id > 0";
            }
        }
        SearchParams searchParams = searchOpenService.getParams(queryStr, identity, filter);
        // searchParams.setdeep
        //设置scroll方式查询
        DeepPaging deep = new DeepPaging();
        //不设置默认为1m表示1分钟，该参数表示本次返回的scrollid的有效期
        deep.setScrollExpire("3m");
        //添加DeepPaging对象参数
        searchParams.setDeepPaging(deep);
        // searchOpenService.getResultJsonObject 返回result获取scrollid
        String scroll_id = null;
        try {
            JSONObject resultJson = searchOpenService.getResultJsonObject(queryStr, searchParams);
            scroll_id = resultJson.getString("scroll_id");
        } catch (Exception e) {
            log.error("查询文档异常：" + e.getMessage());
            return ResponseJson.error("查询文档异常：" + e.getMessage(), null);
        }
        deep.setScrollId(scroll_id);
        searchParams.setDeepPaging(deep);
        // searchParams.setscrollid
        ResponseJson<Set<HashMap<String, Object>>> result = getBrandResult(searchParams, queryStr);
        return result;
    }

    private ResponseJson<Set<HashMap<String, Object>>> getBrandResult(SearchParams searchParams, String queryStr) {
        ResponseJson<Set<HashMap<String, Object>>> result;
        try {
            JSONObject resultJson = searchOpenService.getResultJsonObject(queryStr, searchParams);
            Set<HashMap<String, Object>> maps = new HashSet<>();
            if (1 == resultJson.getInt("status")) {
                JSONArray pageData = resultJson.getJSONArray("items");
                for (int i = 0; i < pageData.length(); i++) {
                    JSONObject json = pageData.getJSONObject(i);
                    int brandId = json.getInt("p_brand_id");
                    String brandName = json.getString("p_brand_name");
                    if (brandId > 0 && StringUtils.isNotEmpty(brandName)) {
                        HashMap<String, Object> map = new HashMap<>();
                        map.put("id", brandId);
                        map.put("name", brandName);
                        maps.add(map);
                    }
                }
                // 阿里云查询出json转换成商品pojo
                result = ResponseJson.success(maps);
            } else {
                result = ResponseJson.error("未查询到文档记录", null);
            }
        } catch (Exception e) {
            log.error("查询文档异常：" + e.getMessage());
            result = ResponseJson.error("查询文档异常：" + e.getMessage(), null);
        }
        return result;
    }

    /**
     * 根据分类Id搜索商品
     *
     * @param id        bigTypeID/smallTypeID/tinyTypeID
     * @param idType    id类型：1一级分类，2二级分类，3三级分类
     * @param identity  : 0个人，1协销，2会员机构，3供应商，4普通机构
     * @param pageNum   页码
     * @param pageSize  每页数量
     * @param sortField 排序字段
     * @param sortType  升降序0/1
     * @return JsonStr(list)
     */
    @Override
    public ResponseJson<String> queryProductByType(Integer id, Integer idType, String brandIds, Integer identity, Integer newFlag, Integer promotionFlag, int pageNum, int pageSize, String sortField, Integer sortType) {
        String queryStr = "";
        if (idType == 1) {
            queryStr = "p_bigtype:'" + id + "'";
        } else if (idType == 2) {
            queryStr = "p_smalltype:'" + id + "'";
        } else if (idType == 3) {
            queryStr = "p_tinytype:'" + id + "'";
        } else {
            return ResponseJson.error("idType参数错误", null);
        }
        int requestSize = pageNum * pageSize;
        int requestPageSize = requestSize;
        if (requestSize > SEARCH_MAX_NUM) {
            requestPageSize = (int) Math.floor(SEARCH_MAX_NUM / pageSize) * pageSize;
        }
        List<String> filterList = new ArrayList<>();
        if (newFlag == 1) {
            filterList.add("p_newvalidflag = 1");
        }
        if (promotionFlag == 1) {
            filterList.add("p_promotions_id > 0");
        }
        if (!StringUtils.isEmpty(brandIds) && !"null".equals(brandIds)) {
            StringBuffer brandBuilder = new StringBuffer();
            List<String> brandList = new ArrayList<>();
            String[] split = brandIds.split(",");
            for (String s : split) {
                if (!StringUtils.isEmpty(s) && !"null".equals(s)) {
                    brandList.add(s);
                }
            }
            for (int i = 0; i < brandList.size(); i++) {
                if (i == 0) {
                    brandBuilder.append("p_brand_id = ").append(brandList.get(i));
                } else {
                    brandBuilder.append(" OR ").append("p_brand_id = ").append(brandList.get(i));
                }
            }
            String brandFilter = brandBuilder.toString();
            if (brandFilter.contains("OR")) {
                brandFilter = "(" + brandFilter + ")";
            }
            if (!StringUtils.isEmpty(brandFilter)) {
                filterList.add(brandFilter);
            }
        }
        String filter = "";
        StringBuffer filterBuffer = new StringBuffer();
        if (filterList.size() > 0) {
            for (int i = 0; i < filterList.size(); i++) {
                if (i == 0) {
                    filterBuffer.append(filterList.get(i));
                } else {
                    filterBuffer.append(" AND ").append(filterList.get(i));
                }
            }
            filter = filterBuffer.toString();
        }
        SearchParams searchParams = searchOpenService.getScrollProductParams(queryStr, identity, requestPageSize, sortField, sortType);
        String thisFilter = searchParams.getFilter();
        if (StringUtils.isNotEmpty(filter)) {
            thisFilter = thisFilter + " AND " + filter;
        }
        searchParams.setFilter(thisFilter);
        // 阿里云搜索(滚动查询)
        ResponseJson<String> result = getScrollProductResult(searchParams, queryStr, requestPageSize, pageNum, pageSize);
        if (0 == result.getCode()) {
            return result;
        } else {
            // 阿里云搜索失败，再次从数据库搜索
            if (idType == 1) {
                return queryProductFromDatabase(pageNum, pageSize, identity, null, null, id, null, null, null, sortField, sortType);
            } else if (idType == 2) {
                return queryProductFromDatabase(pageNum, pageSize, identity, null, null, null, id, null, null, sortField, sortType);
            } else {
                return queryProductFromDatabase(pageNum, pageSize, identity, null, null, null, null, id, null, sortField, sortType);
            }
        }
    }

    /**
     * 根据小程序运营分类Id搜索商品
     *
     * @param id        运营级分类Id
     * @param identity  用户身份 1:协销， 2:会员机构
     * @param pageNum   页码
     * @param pageSize  每页数量
     * @param sortField 排序字段
     * @param sortType  升降序0/1
     * @return JsonStr(list)
     */
    @Override
    public ResponseJson<String> queryProductByClassify(Integer id, Integer identity, int pageNum, int pageSize, String sortField, Integer sortType) {
        String queryStr = "p_classify:'" + id + "'";
        int requestSize = pageNum * pageSize;
        int requestPageSize = requestSize;
        if (requestSize > SEARCH_MAX_NUM) {
            requestPageSize = (int) Math.floor(SEARCH_MAX_NUM / pageSize) * pageSize;
        }
        SearchParams searchParams = searchOpenService.getScrollProductParams(queryStr, identity, requestPageSize, sortField, sortType);
        // 阿里云搜索(滚动查询)
        ResponseJson<String> result = getScrollProductResult(searchParams, queryStr, requestPageSize, pageNum, pageSize);
        if (0 == result.getCode()) {
            return result;
        } else {
            // 阿里云搜索失败，再次从数据库搜索
            return queryProductFromDatabase(pageNum, pageSize, identity, null, null, null, null, null, id, sortField, sortType);
        }
    }

    /**
     * 根据供应商Id搜索商品（商铺内搜索）
     *
     * @param id        供应商Id
     * @param keyword   搜索关键字
     * @param identity  用户身份 1:协销， 2:会员机构
     * @param pageNum   页码
     * @param pageSize  每页数量
     * @param sortField 排序字段
     * @param sortType  升降序0/1
     * @return JsonStr(list)
     */
    @Override
    public ResponseJson<String> querySupplierProduct(Integer id, String keyword, Integer identity, int pageNum, int pageSize, String sortField, Integer sortType) {
        if (null == id) {
            return ResponseJson.error("请提供供应商id", null);
        }
        ResponseJson<String> result;
        if (StringUtils.isEmpty(keyword)) {
            String queryStr = "p_supplier:'" + id + "'";
            int requestSize = pageNum * pageSize;
            int requestPageSize = requestSize;
            if (requestSize > SEARCH_MAX_NUM) {
                requestPageSize = (int) Math.floor(SEARCH_MAX_NUM / pageSize) * pageSize;
            }
            SearchParams searchParams = searchOpenService.getScrollProductParams(queryStr, identity, requestPageSize, sortField, sortType);
            result = getScrollProductResult(searchParams, queryStr, requestPageSize, pageNum, pageSize);
        } else {
            String queryStr = "product:'" + keyword + "'";
            String filter = "p_supplier_id=" + id;
            result = queryProduct(queryStr, filter, identity, pageNum, pageSize, sortField, sortType);
        }
        if (0 == result.getCode()) {
            return result;
        } else {
            // 阿里云搜索失败，再次从数据库搜索
            return queryProductFromDatabase(pageNum, pageSize, identity, keyword, id, null, null, null, null, sortField, sortType);
        }
    }

    /**
     * 获取数据库商品
     *
     * @param num         页码
     * @param size        每页数量
     * @param identity    用户身份
     * @param keyword     关键词
     * @param shopId      供应商id
     * @param bigTypeId   一级分类id
     * @param smallTypeId 二级分类id
     * @param tinyTypeId  三级分类id
     * @param classifyId  小程序运营分类id
     * @param sortField   排序类型
     * @param sortType    排序顺序
     */
    private ResponseJson<String> queryProductFromDatabase(int num, int size, Integer identity, String keyword, Integer shopId,
                                                          Integer bigTypeId, Integer smallTypeId, Integer tinyTypeId, Integer classifyId, String sortField, Integer sortType) {
        PageHelper.startPage(num, size);
        List<ProductListVo> productList = searchMapper.queryProduct(identity, keyword, shopId, bigTypeId, smallTypeId, tinyTypeId, classifyId, sortField, sortType);
        productList.forEach(product -> {
            product.setPriceGrade(priceUtilService.getPriceGrade(product.getPrice()));
            product.setPrice(0d);
        });
        PaginationVo<ProductListVo> pageData = new PaginationVo<>(productList);
        int total = pageData.getTotalRecord();
        JSONObject pageObj = new JSONObject();
        pageObj.put("total", total);
        pageObj.put("items", productList);
        log.info(">>>>>>数据库容错查询: pageSize(" + size + "),pageNum(" + size + "),total(" + total + ")");
        if (productList.size() > 0) {
            return ResponseJson.success(pageObj.toString());
        } else {
            return ResponseJson.error("未查询到文档记录(数据库)", null);
        }
    }

    /**
     * 查询商品（阿里云搜索）
     *
     * @param queryStr  查询类型及参数
     * @param num       页码
     * @param size      每页数量
     * @param sortField 排序字段
     * @param sortType  升降序
     */
    private ResponseJson<String> queryProduct(String queryStr, String filter, Integer identity, int num, int size, String sortField, Integer sortType) {
        SearchParams searchParams;
        int requestSize = num * size;
        if (requestSize > SEARCH_MAX_NUM) {
            searchParams = searchOpenService.getProductParams(queryStr, filter, identity, num, size, sortField, sortType);
        } else {
            // 由于阿里云搜索机制问题（分页数据重复），搜索500条以内数据手动分页。
            searchParams = searchOpenService.getProductParams(queryStr, filter, identity, 1, requestSize, sortField, sortType);
        }
        try {
            // 查询推送
            JSONObject result = searchOpenService.getResultJsonObject(queryStr, searchParams);
            if (1 == result.getInt("status")) {
                int total = result.getInt("total");
                int totalPage = (int) Math.ceil((double) total / size);
                JSONArray resultArr = result.getJSONArray("items");
                JSONArray pageData = new JSONArray();
                if (requestSize > SEARCH_MAX_NUM) {
                    pageData = resultArr;
                } else {
                    if (resultArr.length() > 0) {
                        int baseNum = (num - 1) * size;
                        for (int i = 0; i < size; i++) {
                            int index = baseNum + i;
                            int currentTotal = requestSize;
                            if (totalPage == num) {
                                currentTotal = total;
                            }
                            if (index < currentTotal) {
                                JSONObject item = resultArr.getJSONObject(index);
                                pageData.put(i, item);
                            } else {
                                break;
                            }
                        }
                    }
                }
                // 阿里云查询出json转换成商品pojo
                List<ProductListVo> productList = Json2PojoUtil.toProductList(pageData);
                JSONObject pageObj = new JSONObject();
                pageObj.put("total", total);
                pageObj.put("items", productList);
                log.info(">>>>>>pageResult(" + queryStr + "): pageSize(" + size + "),pageNum(" + num + "),total(" + total + ")");
                return ResponseJson.success(pageObj.toString());
            } else {
                return ResponseJson.error("未查询到文档记录", null);
            }
        } catch (OpenSearchClientException | OpenSearchException | JSONException e) {
            log.error("查询文档异常：" + e.getMessage());
            return ResponseJson.error("查询文档异常：" + e.getMessage(), null);
        }
    }

    /**
     * 滚动查询
     *
     * @param searchParams    查询参数对象
     * @param queryStr        查询类型及参数串
     * @param requestPageSize 每次scroll数量
     * @param pageNum         页码
     * @param pageSize        每页数量
     * @return list
     */
    private ResponseJson<String> getScrollProductResult(SearchParams searchParams, String queryStr, int requestPageSize, int pageNum, int pageSize) {
        ResponseJson<String> result;
        try {
            JSONObject pageObj = searchOpenService.deepPagingForParams(searchParams, queryStr, SEARCH_MAX_NUM, requestPageSize, pageNum, pageSize);
            if (1 == pageObj.getInt("status")) {
                JSONArray pageData = pageObj.getJSONArray("items");
                // 阿里云查询出json转换成商品pojo
                List<ProductListVo> productList = Json2PojoUtil.toProductList(pageData);
                pageObj.put("items", productList);
                result = ResponseJson.success(pageObj.toString());
            } else {
                result = ResponseJson.error("未查询到文档记录", null);
            }
        } catch (OpenSearchClientException | OpenSearchException | JSONException e) {
            log.error("查询文档异常：" + e.getMessage());
            result = ResponseJson.error("查询文档异常：" + e.getMessage(), null);
        }
        return result;
    }

    /**
     * 根据用户ID查找历史记录
     *
     * @param userId 用户Id
     */
    @Override
    public ResponseJson<List<SearchHistoryPo>> getSearchHistory(Integer userId) {
        List<SearchHistoryPo> historyList = searchMapper.getHistoryList(userId);
        return ResponseJson.success(historyList);
    }

    /**
     * 保存搜索历史记录
     *
     * @param userId  用户Id
     * @param keyword 搜索关键字
     */
    @Override
    public ResponseJson<Void> addSearchHistory(Integer userId, String keyword) {
        //保存并删除大于10条的历史记录
        SearchHistoryPo historyRecord = new SearchHistoryPo();
        historyRecord.setUserId(userId);
        historyRecord.setSearchDate(new Date());
        historyRecord.setSearchWord(keyword);
        historyRecord.setDelFlag(0);
        Integer recordId = searchMapper.getHistoryIdByWord(keyword, userId);
        if (null != recordId && recordId > 0) {
            //更新
            historyRecord.setId(recordId);
            searchMapper.updateSearchHistoryById(historyRecord);
        } else {
            // 新增
            searchMapper.insertSearchHistory(historyRecord);
        }
        int count = searchMapper.getHistoryCount(userId);
        if (count > 10) {
            // 删除大于10条的历史记录
            searchMapper.deleteSearchHistory(userId);
        }
        return ResponseJson.success(null);
    }

    /**
     * 根据用户ID删除历史记录
     *
     * @param userId 用户Id
     */
    @Override
    public ResponseJson<Void> deleteSearchHistory(Integer userId) {
        // 删除用户所有历史记录
        searchMapper.deleteAllSearchHistory(userId);
        return ResponseJson.success(null);
    }

    /**
     * 产品仪器热搜词
     */
    @Override
    public ResponseJson<Map<String, Object>> getHotSearchTerms() {
        //产品
        List<HotSearchVo> productHotSearch = getHotSearch(1, 2);
        //仪器
        List<HotSearchVo> instrumentHotSearch = getHotSearch(2, 2);
        Map<String, Object> map = new HashMap<>(2);
        map.put("productHotSearch", productHotSearch);
        map.put("instrumentHotSearch", instrumentHotSearch);
        return ResponseJson.success(map);
    }


    private List<HotSearchVo> getHotSearch(Integer typeSort, Integer source) {
        List<Integer> pageIds = pageMapper.getPageIdByTypeSort(typeSort);
        List<HotSearchVo> productHotSearch = new ArrayList<>();
        if (pageIds != null) {
            productHotSearch = pageMapper.getHotSearchByPageIds(pageIds, source);
        }
        productHotSearch.forEach(h -> {
            String link = h.getLink();
            h.setLinkType(AppletsLinkUtil.getLinkType(link));
            h.setLinkParam(AppletsLinkUtil.getLinkParam(h.getLinkType(), link));
        });
        return productHotSearch;
    }

    /**
     * 统计关键词及次数
     *
     * @param fromType
     * @param path
     * @param keyword
     * @return
     */
    @Override
    public ResponseJson conKeyword(Integer fromType, String path, String keyword) {
        Date date = new Date();
        SimpleDateFormat sf = new SimpleDateFormat("yyyy-MM-dd");
        sf.format(date);
        //根据关键词和来源查询数据库是否存在（存在来源也相同时增加次数,存在但来源不同时和不存在则新增）
        List<SearchFrequencyVo> searchFrequencyVoList = searchFrequencyMapper.getInfoBykeyword(keyword, fromType);
        if (null != searchFrequencyVoList && searchFrequencyVoList.size() > 0) {
            //存在 统计次数
            Integer frequency = searchFrequencyVoList.get(0).getFrequency() + 1;
            searchFrequencyMapper.upFrequencyById(searchFrequencyVoList.get(0).getId(), frequency);
        } else {
            //不存在 新增
            SearchFrequencyVo sea = new SearchFrequencyVo();
            sea.setKeyword(keyword);
            sea.setFrequency(1);
            sea.setFromSearch(fromType);
            sea.setSearchTime(new java.sql.Date(date.getTime()));
            searchFrequencyMapper.saveInfo(sea);
        }
        return ResponseJson.success();
    }

    /**
     * 获取已加入关键词库的关键词进行搜索联动
     * 从redis获取，获取不到则去数据库获取
     *
     * @return
     */
    @Override
    public List<SearchKeywordyVo> getKeywordList(String keyword) {
        //先从reids中获取keyword值，不存在时在查询数据库
        List<SearchKeywordyVo> searchFrequencyVos = new ArrayList<>();
        if (redisService.getExpireTime(keyword) > 0) {
            log.info("-------------获取redis中的数据--------------");
            searchFrequencyVos = com.alibaba.fastjson.JSONArray.parseArray(redisService.get(keyword).toString(), SearchKeywordyVo.class);
        } else {
            log.info("-------------获取数据库中的数据--------------");
            searchFrequencyVos = searchFrequencyMapper.getKeywordList(keyword);
        }
        return searchFrequencyVos;
    }

    /**
     * redis缓存关键词（把所有的关键词整合到一个字符串中）
     * 用时从redis取出转成list集合返回给前端进行联动
     */
    @Override
    public void conKeyWord() {
        List<SearchKeywordyVo> keywordList = searchFrequencyMapper.getKeywordList(null);
        for (SearchKeywordyVo searchFrequency : keywordList) {
            String str = searchFrequency.getKeyword();
            String key = "";
            for (int i = 0; i < str.length(); i++) {
                key += str.charAt(i);
                List<SearchKeywordyVo> searchFrequencyVos = searchFrequencyMapper.getvalueList(key);
                //有值的字段才转
                String keyword = com.alibaba.fastjson.JSONObject.toJSONString(searchFrequencyVos);
                redisService.set(key, keyword, 60L * 60 * 24 * 30);
            }
        }
    }

    @Override
    public List<SearchKeywordyVo> getKeywordLIstByData(String keyword) {
        return searchFrequencyMapper.getKeywordList(keyword);
    }
}
