package com.caimei365.commodity.service.impl;

import com.caimei365.commodity.components.PriceUtilService;
import com.caimei365.commodity.mapper.PriceMapper;
import com.caimei365.commodity.mapper.SellerMapper;
import com.caimei365.commodity.mapper.ShopMapper;
import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.vo.CombinationVo;
import com.caimei365.commodity.model.vo.PaginationVo;
import com.caimei365.commodity.model.vo.ProductItemVo;
import com.caimei365.commodity.service.PageService;
import com.caimei365.commodity.service.SellerService;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.atomic.AtomicReference;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/4/23
 */
@Service
@Slf4j
public class SellerServiceImpl implements SellerService {
    @Value("${caimei.wwwDomain}")
    private String domain;
    @Resource
    private SellerMapper sellerMapper;
    @Resource
    private PriceUtilService priceUtilService;
    @Resource
    private PageService pageService;
    @Resource
    private PriceMapper priceMapper;
    @Resource
    private ShopMapper shopMapper;

    /**
     * 协销搜索商品(单一)
     *
     * @param searchWord 搜索关键字
     * @param clubUserId 机构用户Id
     * @param pageNum    页码
     * @param pageSize   每页数量
     */
    @Override
    public ResponseJson<PaginationVo<ProductItemVo>> searchSingleProducts(String searchWord, Integer clubUserId, int pageNum, int pageSize) {
        if (null == clubUserId) {
            return ResponseJson.error("参数错误：机构用户Id不能为空！", null);
        }
        PageHelper.startPage(pageNum, pageSize);
        List<ProductItemVo> productList = sellerMapper.getSingleProductList(searchWord);
        productList.forEach(product -> {
            // 设置商品主图及价格
            priceUtilService.setProductDetails(clubUserId, product, 0);
        });
        PaginationVo<ProductItemVo> pageData = new PaginationVo<>(productList);
        return ResponseJson.success(pageData);
    }

    /**
     * 协销搜索商品(组合)
     *
     * @param searchWord 搜索关键字
     * @param clubUserId 机构用户Id
     * @param pageNum    页码
     * @param pageSize   每页数量
     */
    @Override
    public ResponseJson<PaginationVo<CombinationVo>> searchCombinationProducts(String searchWord, Integer clubUserId, int pageNum, int pageSize) {
        if (null == clubUserId) {
            return ResponseJson.error("参数错误：机构用户Id不能为空！", null);
        }
        PageHelper.startPage(pageNum, pageSize);
        List<CombinationVo> combinationList = sellerMapper.getCombinationList(searchWord);
        combinationList.forEach(combination -> {
            // 初始化商品数据，提供前端使用
            combination.setProductKind(0);
            combination.setProductTotalNum(0);
            combination.setProductTotalAmount(new BigDecimal(0));
            // 获取组合对应的商品集合
            List<ProductItemVo> productList = sellerMapper.getCombinationProductList(combination.getId());
            productList.forEach(product -> {
                // 初始化商品数据，提供前端使用
                product.setInitProductNum(0);
                product.setTotalPrice(0d);
                // 设置商品主图及价格
                priceUtilService.setProductDetails(clubUserId, product, 1);
                //优惠券标识
                Boolean couponsLogo = pageService.setCouponsLogo(clubUserId, product.getProductId(), 2);
                product.setCouponsLogo(couponsLogo);
            });
            combination.setCombinationProductList(productList);
        });
        PaginationVo<CombinationVo> pageData = new PaginationVo<>(combinationList);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson<PaginationVo<ProductItemVo>> searchCombinationList(Integer productId, Integer userId, Integer source, int pageNum, int pageSize) {
        Integer combinationId = sellerMapper.findCombination(productId);
        List<ProductItemVo> productList = new ArrayList<>();
        PaginationVo<ProductItemVo> productItemVoPaginationVo = new PaginationVo<>(productList);
        if (combinationId != null) {
            List<Integer> productIdList = sellerMapper.findProductList(combinationId);
            List<Integer> p = new ArrayList<>();
            p.add(productId);
            List<ProductItemVo> pd = sellerMapper.getProductList(p);
            ProductItemVo productItemVo = new ProductItemVo();
            if (pd != null && pd.size() > 0) {
                productItemVo = pd.get(0);
            }
            PageHelper.startPage(pageNum, pageSize);
            productList = sellerMapper.getProductList(productIdList);
            //本商品设置首位
            productList.remove(productItemVo);
            productList.add(0, productItemVo);
            Integer userIdentity = shopMapper.getUserIdentityById(userId);
            // 如果非会员身份剔除会员可见商品
            if (userIdentity != null) {
                if (userIdentity == 0 || userIdentity == 4 || userIdentity == 6) {
                    productList.removeIf(c -> "1".equals(c.getVisibility()));
                }
            }
            productList.forEach(product -> {
                // 设置商品主图及价格
                priceUtilService.setProductDetails(userId, product, 0);
                //优惠券标识
                Boolean couponsLogo = pageService.setCouponsLogo(userId, product.getProductId(), source);
                product.setCouponsLogo(couponsLogo);
            });
            productItemVoPaginationVo = new PaginationVo<>(productList);
        }
        return ResponseJson.success(productItemVoPaginationVo);
    }

}
